@@ -26,7 +26,7 @@
  *      $Id: bit1024.c,v 1.6 2003/02/13 02:38:41 maf Exp $
  */
 
-#include "ftconfig.h"
+#include "ftinclude.h"
 #include "ftlib.h"
 
 int bit1024_reverse[] = {
@@ -42,7 +42,7 @@ int bit1024_reverse[] = {
 3, 4, 4, 5, 4, 5, 5, 6, 4, 5, 5, 6, 5, 6, 6, 7, 3, 4, 4, 5, 4, 5, 5, 6, 4, 5,
 5, 6, 5, 6, 6, 7, 4, 5, 5, 6, 5, 6, 6, 7, 5, 6, 6, 7, 6, 7, 7, 8};
 
-u_int bit1024_pow2[] = {
+unsigned int bit1024_pow2[] = {
 1U, 2U, 4U, 8U, 16U, 32U, 64U, 128U, 256U, 512U, 1024U, 2048U, 4096U, 8192U,
 16384U, 32768U, 65536U, 131072U, 262144U, 524288U, 1048576U, 2097152U,
 4194304U, 8388608U, 16777216U, 33554432U, 67108864U, 134217728U, 268435456U,
@@ -57,7 +57,7 @@ void bit1024_store(int d, struct bit1024 *old)
 
 int bit1024_count(struct bit1024 *b)
 {
-  register int i, c;
+  int i, c;
 
   for (i = 0, c = 0; i < 32; ++i) {
     c += bit1024_reverse[(b->n[i]&0x000000FF)]+
