@@ -53,7 +53,7 @@
 
 int load_dir(char *prefix, struct ftfile_entries *fte, int flags, int *depth);
 
-extern int debug;
+#define debug 0
 
 /*
  * function: ftfile_entry_new
@@ -276,7 +276,7 @@ int ftfile_loaddir(struct ftfile_entries *fte, char *dir, int flags)
  *          >= 0 ok
 */
 int ftfile_add_tail(struct ftfile_entries *fte, char *fname, off_t size,
-  u_int32 start)
+  uint32_t start)
 {
   struct ftfile_entry *n1;
 
@@ -310,9 +310,9 @@ int ftfile_add_tail(struct ftfile_entries *fte, char *fname, off_t size,
 */
 int ftfile_expire (struct ftfile_entries *fte, int doit, int curbytes)
 {
-  u_int i;
-  struct ftfile_entry *n1;
-  u_int64 bytes;
+  unsigned int i;
+  struct ftfile_entry *n1, *n2;
+  uint64_t bytes;
 
   /*
    * if max_files is set, remove files starting at the head of the list until
@@ -323,15 +323,20 @@ int ftfile_expire (struct ftfile_entries *fte, int doit, int curbytes)
   bytes = 0;
 
   if (fte->max_files && (fte->num_files > fte->max_files)) {
+    n2 = NULL;
     FT_TAILQ_FOREACH(n1, &fte->head, chain) {
+      if (n2 != NULL) {
+	ftfile_entry_free(n2);
+	n2 = NULL;
+      }
       fterr_info("remove/1 %s", n1->name);
       bytes += n1->size;
       ++i;
       if (doit) {
+        n2 = n1;
         FT_TAILQ_REMOVE(&fte->head, n1, chain);
         if (unlink(n1->name) == -1) 
           fterr_warn("unlink(%s)", n1->name);
-        ftfile_entry_free(n1);
       } /* doit */
       if ((fte->num_files - i) <= fte->max_files)
         break;
@@ -340,6 +345,10 @@ int ftfile_expire (struct ftfile_entries *fte, int doit, int curbytes)
       fte->num_files -= i;
       fte->num_bytes -= bytes;
     } /* doit */
+    if (n2 != NULL) {
+      ftfile_entry_free(n2);
+      n2 = NULL;
+    }
   } /* if */
 
   if (debug)
@@ -354,15 +363,20 @@ int ftfile_expire (struct ftfile_entries *fte, int doit, int curbytes)
    */
 
   if (fte->max_bytes && (fte->num_bytes+curbytes > fte->max_bytes)) {
+    n2 = NULL;
     FT_TAILQ_FOREACH(n1, &fte->head, chain) {
+      if (n2 != NULL) {
+	ftfile_entry_free(n2);
+	n2 = NULL;
+      }
       fterr_info("remove/2 %s", n1->name);
       bytes += n1->size;
       ++i;
       if (doit) {
+        n2 = n1;
         FT_TAILQ_REMOVE(&fte->head, n1, chain);
         if (unlink(n1->name) == -1) 
           fterr_warn("unlink(%s)", n1->name);
-        ftfile_entry_free(n1);
       } /* doit */
       if ((fte->num_bytes+curbytes - bytes) <= fte->max_bytes)
         break;
@@ -371,6 +385,10 @@ int ftfile_expire (struct ftfile_entries *fte, int doit, int curbytes)
       fte->num_files -= i;
       fte->num_bytes -= bytes;
     } /* doit */
+    if (n2 != NULL) {
+      ftfile_entry_free(n2);
+      n2 = NULL;
+    }
   } /* if */
 
   if (debug)
@@ -410,7 +428,7 @@ int ftfile_dump(struct ftfile_entries *fte)
  * 
  */
 void ftfile_pathname(char *buf, int bsize, int nest, struct ftver ftv,
- int done, u_int32 ftime)
+ int done, time_t ftime)
 {
   struct tm *tm;
   char *prefix, dbuf[64];
@@ -418,7 +436,7 @@ void ftfile_pathname(char *buf, int bsize, int nest, struct ftver ftv,
   char gmt_sign;
   int tm_gmtoff;
   
-  if (!(tm = localtime ((time_t*)&ftime))) {
+  if (!(tm = localtime (&ftime))) {
     snprintf(buf, bsize, ".");
   }
 
@@ -499,7 +517,7 @@ void ftfile_pathname(char *buf, int bsize, int nest, struct ftver ftv,
  * returns -1 on error
  * 
  */
-int ftfile_mkpath(u_int32 ftime, int nest)
+int ftfile_mkpath(time_t ftime, int nest)
 {
   struct tm *tm;
   char buf[32];
@@ -512,7 +530,7 @@ int ftfile_mkpath(u_int32 ftime, int nest)
   if ((nest > 3) || (nest < -3))
     return -1;
 
-  if (!(tm = localtime ((time_t*)&ftime)))
+  if (!(tm = localtime (&ftime)))
     return -1;
 
   if (nest == -1)
@@ -762,13 +780,19 @@ void ftfile_free(struct ftfile_entries *fte)
 {
   struct ftfile_entry *n1, *n2;
 
+  n2 = NULL;
   FT_TAILQ_FOREACH(n1, &fte->head, chain) {
+    if (n2 != NULL) {
+      ftfile_entry_free(n2);
+      n2 = NULL;
+    }
     FT_TAILQ_REMOVE(&fte->head, n1, chain);
     n2 = n1;
-    n1 = FT_TAILQ_NEXT(n1, chain);
+  }
+
+  if (n2 != NULL) {
     ftfile_entry_free(n2);
-    if (!n1)
-      break;
+    n2 = NULL;
   }
 
 } /* ftfile_free */
