@@ -26,7 +26,7 @@
  *      $Id: ftio.c,v 1.47 2003/02/24 00:51:47 maf Exp $
  */
 
-#include "ftconfig.h"
+#include "ftinclude.h"
 #include "ftlib.h"
 
 #include <sys/time.h>
@@ -47,20 +47,60 @@
 #include <fcntl.h>
 #include <zlib.h>
 
-#if HAVE_STRINGS_H
- #include <strings.h>
-#endif
-#if HAVE_STRING_H
-  #include <string.h>
-#endif
-
 #if HAVE_MMAP
  #include <sys/types.h>
  #include <sys/mman.h>
  #include <sys/stat.h>
 #endif
 
-int readn(register int fd, register void *ptr, register int nbytes);
+/*
+ * function: readn
+ *
+ * read()'s n bytes from fd
+ * returns # of bytes read, or -1 for error
+ */
+static int readn(int fd, void *ptr, int nbytes) {
+
+  int nleft, nread;
+
+  nleft = nbytes;
+  while (nleft > 0) {
+      nread = read(fd, ptr, nleft);
+      if (nread < 0)
+        return nread;
+      else if (nread == 0)
+        break;
+
+      nleft -= nread;
+      ptr = (char*)ptr + nread;
+  }
+  return (nbytes - nleft);
+} /* readn */
+
+
+/* From Stevens
+ *
+ * function: writen
+ *
+ *  write()'s n bytes to fd.
+ *  returns # of bytes written, or -1 for error
+ */
+static int writen(int fd, const void *ptr, int nbytes) {
+
+  int nleft, nwritten;
+
+  nleft = nbytes;
+  while (nleft > 0) {
+    nwritten = write(fd, ptr, nleft);
+    if (nwritten <= 0)
+      return(nwritten); /* error */
+
+    nleft -= nwritten;
+    ptr = (char*)ptr + nwritten;
+  }
+  return(nbytes - nleft);
+} /* writen */
+
 
 /*
  * function: ftio_init
@@ -103,23 +143,23 @@ int ftio_init(struct ftio *ftio, int fd, int flag)
 #if HAVE_MMAP
 
     if (flag & FT_IO_FLAG_MMAP) {
+      /* Instead of failing completely when MMAP fails, fallback to the usual 
+       * way of doing things 
+       */
 
-      if (fstat(ftio->fd, &sb) < 0) {
-         fterr_warn("stat()");
-         goto ftio_init_out;
+      if (fstat(ftio->fd, &sb) == 0) {
+        if ((ftio->mr = mmap(NULL, sb.st_size, PROT_READ|PROT_WRITE, MAP_PRIVATE, 
+            ftio->fd, 0)) != MAP_FAILED) {
+          ftio->mr_size = sb.st_size;
+          ftio->flags |= FT_IO_FLAG_MMAP;
+        } else {
+          ftio->mr = NULL;
+          // fterr_warn("mmap()");
+        }
+      } else {
+        // fterr_warn("stat()");
       }
 
-      ftio->mr_size = sb.st_size;
-
-      if ((ftio->mr = mmap((caddr_t)0L, ftio->mr_size, PROT_READ|PROT_WRITE,
-         MAP_PRIVATE,
-         ftio->fd, (off_t)0L)) == MAP_FAILED) {
-         fterr_warn("mmap()");
-         goto ftio_init_out;
-      }
-
-      ftio->flags |= FT_IO_FLAG_MMAP;
-
     } /* FT_IO_FLAG_MMAP */
 
 #endif /* HAVE_MMAP */
@@ -130,7 +170,7 @@ int ftio_init(struct ftio *ftio, int fd, int flag)
       goto ftio_init_out;
     }
 
-    if (flag & FT_IO_FLAG_MMAP) {
+    if (ftio->flags & FT_IO_FLAG_MMAP) {
       ftio->d_start = ftio->fth.enc_len;
       ftio->d_end = sb.st_size;
     }
@@ -209,7 +249,7 @@ int ftio_init(struct ftio *ftio, int fd, int flag)
 
 #ifdef HAVE_MMAP
  
-      if (flag & FT_IO_FLAG_MMAP) {
+      if (ftio->flags & FT_IO_FLAG_MMAP) {
 
         ftio->zs.avail_in = sb.st_size - ftio->fth.enc_len;
         ftio->zs.next_in = (Bytef*)ftio->mr+ftio->fth.enc_len;
@@ -349,7 +389,7 @@ void ftio_set_z_level(struct ftio *ftio, int z_level)
  *
  * Set the # of flows for a ftio stream header
  */
-void ftio_set_flows_count(struct ftio *ftio, u_int32 n)
+void ftio_set_flows_count(struct ftio *ftio, uint32_t n)
 {
   ftio->fth.fields |= FT_FIELD_FLOW_COUNT;
   ftio->fth.flows_count = n;
@@ -492,7 +532,7 @@ int ftio_set_cap_hostname(struct ftio *ftio, char *hostname)
  *
  * Set the corrupt flows header field
  */
-void ftio_set_corrupt(struct ftio *ftio, u_int32 n)
+void ftio_set_corrupt(struct ftio *ftio, uint32_t n)
 {
   ftio->fth.fields |= FT_FIELD_PKT_CORRUPT;
   ftio->fth.pkts_corrupt = n;
@@ -503,7 +543,7 @@ void ftio_set_corrupt(struct ftio *ftio, u_int32 n)
  *
  * Set the lost flows header field
  */
-void ftio_set_lost(struct ftio *ftio, u_int32 n)
+void ftio_set_lost(struct ftio *ftio, uint32_t n)
 {
   ftio->fth.fields |= FT_FIELD_FLOW_LOST;
   ftio->fth.flows_lost = n;
@@ -514,7 +554,7 @@ void ftio_set_lost(struct ftio *ftio, u_int32 n)
  *
  * Set the reset sequence header field
  */
-void ftio_set_reset(struct ftio *ftio, u_int32 n)
+void ftio_set_reset(struct ftio *ftio, uint32_t n)
 {
   ftio->fth.fields |= FT_FIELD_SEQ_RESET;
   ftio->fth.seq_reset = n;
@@ -526,7 +566,7 @@ void ftio_set_reset(struct ftio *ftio, u_int32 n)
  *
  * Set the exporter ip header field
  */
-void ftio_set_xip(struct ftio *ftio, u_int32 ip)
+void ftio_set_xip(struct ftio *ftio, uint32_t ip)
 {
   ftio->fth.fields |= FT_FIELD_EXPORTER_IP;
   ftio->fth.exporter_ip = ip;
@@ -537,7 +577,7 @@ void ftio_set_xip(struct ftio *ftio, u_int32 ip)
  *
  * Set the header time for a ftio stream
  */
-void ftio_set_cap_time(struct ftio *ftio, u_int32 start, u_int32 end)
+void ftio_set_cap_time(struct ftio *ftio, uint32_t start, uint32_t end)
 {
   ftio->fth.fields |= FT_FIELD_CAP_START;
   ftio->fth.fields |= FT_FIELD_CAP_END;
@@ -550,7 +590,7 @@ void ftio_set_cap_time(struct ftio *ftio, u_int32 start, u_int32 end)
  *
  * Set the header time for a ftio stream
  */
-void ftio_set_cap_time_start(struct ftio *ftio, u_int32 start)
+void ftio_set_cap_time_start(struct ftio *ftio, uint32_t start)
 {
   ftio->fth.fields |= FT_FIELD_CAP_START;
   ftio->fth.cap_start = start;
@@ -569,32 +609,44 @@ void ftio_get_ver(struct ftio *ftio, struct ftver *ver)
   ver->agg_version = ftio->fth.agg_version;
 }
 
+time_t ftio_uint32_to_time_t(uint32_t val) {
+  return (time_t) val;
+}
+
 /*
  * function: ftio_get_stime
  *
  * Get the starting time from a ftio stream
  */
-u_int32 ftio_get_cap_start(struct ftio *ftio)
+uint32_t ftio_get_cap_start(const struct ftio *ftio)
 {
   return ftio->fth.cap_start;
 }
 
+time_t ftio_get_cap_start_time_t(const struct ftio *ftio) {
+  return ftio_uint32_to_time_t(ftio_get_cap_start(ftio));
+}
+
 /*
  * function: ftio_get_etime
  *
  * Get the ending time from a ftio stream
  */
-u_int32 ftio_get_cap_end(struct ftio *ftio)
+uint32_t ftio_get_cap_end(const struct ftio *ftio)
 {
   return ftio->fth.cap_end;
 }
 
+time_t ftio_get_cap_end_time_t(const struct ftio *ftio) {
+  return ftio_uint32_to_time_t(ftio_get_cap_end(ftio));
+}
+
 /*
  * function: ftio_get_rec_total
  *
  * Get the total records processed from a ftio stream
  */
-u_int64 ftio_get_rec_total(struct ftio *ftio)
+uint64_t ftio_get_rec_total(struct ftio *ftio)
 {
   return ftio->rec_total;
 }
@@ -604,7 +656,7 @@ u_int64 ftio_get_rec_total(struct ftio *ftio)
  *
  * Get the total records processed from a ftio stream
  */
-u_int32 ftio_get_flows_count(struct ftio *ftio)
+uint32_t ftio_get_flows_count(struct ftio *ftio)
 {
   return ftio->fth.flows_count;
 }
@@ -645,7 +697,7 @@ char *ftio_get_comment(struct ftio *ftio)
  *
  * Get header corrupt flows from a ftio stream
 */
-u_int32 ftio_get_corrupt(struct ftio *ftio)
+uint32_t ftio_get_corrupt(struct ftio *ftio)
 {
   return ftio->fth.pkts_corrupt;
 }
@@ -655,7 +707,7 @@ u_int32 ftio_get_corrupt(struct ftio *ftio)
  *
  * Get header lost flows from a ftio stream
 */
-u_int32 ftio_get_lost(struct ftio *ftio)
+uint32_t ftio_get_lost(struct ftio *ftio)
 {
   return ftio->fth.flows_lost;
 }
@@ -864,7 +916,7 @@ void *ftio_read(struct ftio *ftio)
   int n, err;
   void *ret;
   struct fts1rec_compat *compat;
-  u_int32 bleft, boff;
+  uint32_t bleft, boff;
 
   ret = (void*)0L;
 
@@ -1165,7 +1217,7 @@ int ftio_write_header(struct ftio *ftio)
   struct ftheader_gen head_gen;
   struct ftmap_ifname *ftmin;
   struct ftmap_ifalias *ftmia;
-  u_int32 head_off_d;
+  uint32_t head_off_d;
   int n, ret, restore, flip, len;
   char *enc_buf;
 
@@ -1586,6 +1638,20 @@ ftio_write_out:
 
 } /* ftio_write */
 
+static size_t strftime_tz(char *s, size_t max, const time_t timeval) {
+  struct tm tm_struct;
+
+  return strftime(s, max, "%a, %d %b %Y %H:%M:%S %z", localtime_r(&timeval, &tm_struct));
+}
+
+static void fprintf_time(FILE *std, char *format, char cc, const time_t timeval) {
+  char timebuf[128];
+
+  strftime_tz(timebuf, sizeof(timebuf), timeval);
+
+  fprintf(std, format, cc, timebuf);
+}
+
 /*
  * function: ftio_header_print
  *
@@ -1602,8 +1668,8 @@ void ftio_header_print(struct ftio *ftio, FILE *std, char cc)
   char agg_ver, agg_method;
   char *agg_name;
   char fmt_buf[32];
-  u_int32 flags, fields;
-  u_long period;
+  uint32_t flags, fields;
+  uint32_t period;
   int n, streaming2;
 
   fth = &ftio->fth;
@@ -1638,25 +1704,19 @@ void ftio_header_print(struct ftio *ftio, FILE *std, char cc)
     }
   }
 
-  if (!streaming2)
-    if (fields & FT_FIELD_CAP_START)
-      fprintf(std, "%c capture start:        %s", cc,
-        ctime((time_t*)&fth->cap_start));
+  if ((!streaming2) && (fields & FT_FIELD_CAP_START))
+    fprintf_time(std, "%c capture start:        %s\n", cc, ftio_get_cap_start_time_t(ftio));
 
   if (!streaming2) {
-
     if ((flags & FT_HEADER_FLAG_DONE) || (flags & FT_HEADER_FLAG_PRELOADED)) {
-
       if (fields & FT_FIELD_CAP_END)
-        fprintf(std, "%c capture end:          %s", cc,
-          ctime((time_t*)&fth->cap_end));
-
-      period = fth->cap_end - fth->cap_start;
-      if ((fields & FT_FIELD_CAP_END) && (fields & FT_FIELD_CAP_START))
-        fprintf(std, "%c capture period:       %lu seconds\n", cc, period);
+        fprintf_time(std, "%c capture end:          %s\n", cc, ftio_get_cap_end_time_t(ftio));
 
+      if ((fields & FT_FIELD_CAP_END) && (fields & FT_FIELD_CAP_START)) {
+        period = fth->cap_end - fth->cap_start;
+        fprintf(std, "%c capture period:       %" PRIu32 " seconds\n", cc, period);
+      }
     }
-
   }
 
   fprintf(std, "%c compress:             %s\n", cc, 
@@ -1762,23 +1822,23 @@ void ftio_header_print(struct ftio *ftio, FILE *std, char cc)
 
   if (!streaming2)
     if (fields & FT_FIELD_FLOW_LOST)
-      fprintf(std, "%c lost flows:           %lu\n", cc,
-        (u_long)fth->flows_lost);
+      fprintf(std, "%c lost flows:           %" PRIu32 "\n", cc,
+        (uint32_t)fth->flows_lost);
 
   if (!streaming2)
     if (fields & FT_FIELD_FLOW_MISORDERED)
       fprintf(std,
-        "%c misordered flows:     %lu\n", cc, (u_long)fth->flows_misordered);
+        "%c misordered flows:     %" PRIu32 "\n", cc, (uint32_t)fth->flows_misordered);
 
   if (!streaming2)
     if (fields & FT_FIELD_PKT_CORRUPT)
       fprintf(std,
-        "%c corrupt packets:      %lu\n", cc, (u_long)fth->pkts_corrupt);
+        "%c corrupt packets:      %" PRIu32 "\n", cc, (uint32_t)fth->pkts_corrupt);
 
   if (!streaming2)
     if (fields & FT_FIELD_SEQ_RESET)
       fprintf(std,
-        "%c sequencer resets:     %lu\n", cc, (u_long)fth->seq_reset);
+        "%c sequencer resets:     %" PRIu32 "\n", cc, (uint32_t)fth->seq_reset);
 
   if (fields & FT_FIELD_COMMENTS)
     fprintf(std, "%c comments:             %s\n", cc, fth->comments);
@@ -1829,7 +1889,7 @@ void ftio_header_print(struct ftio *ftio, FILE *std, char cc)
 void *ftio_rec_swapfunc(struct ftio *ftio)
 {
 
-  u_int8 s_ver, d_ver, agg_ver, agg_method;
+  uint8_t s_ver, d_ver, agg_ver, agg_method;
   void *ret;
 
   s_ver = ftio->fth.s_version;
@@ -2097,10 +2157,10 @@ int ftrec_size(struct ftver *ver)
  * Return the FT_XFIELD* based on the d_version and agg_method
  *
  */
-u_int64 ftrec_xfield(struct ftver *ver)
+uint64_t ftrec_xfield(struct ftver *ver)
 {
 
-  u_int64 ret;
+  uint64_t ret;
 
    switch (ver->d_version) {
 
@@ -2214,7 +2274,7 @@ u_int64 ftrec_xfield(struct ftver *ver)
  * Return the FT_XFIELD*
  *
  */
-u_int64 ftio_xfield(struct ftio *ftio)
+uint64_t ftio_xfield(struct ftio *ftio)
 {
   struct ftver ver;
 
@@ -2247,56 +2307,6 @@ int ftio_rec_size(struct ftio *ftio)
 } /* ftio_rec_size */
 
 
-/*
- * function: readn
- *
- * read()'s n bytes from fd
- * returns # of butes read, or -1 for error
- */
-int readn(register int fd, register void *ptr, register int nbytes)
-{
-
-  int nleft, nread;
-
-  nleft = nbytes;
-  while (nleft > 0) {
-      nread = read(fd, ptr, nleft);
-      if (nread < 0)
-        return nread;
-      else if (nread == 0)
-        break;
-
-      nleft -= nread;
-      (char*)ptr += nread;
-  }
-  return (nbytes - nleft);
-} /* readn */
-
-
-/* From Stevens
- *
- * function: writen
- *
- *  write()'s n bytes to fd.
- *  returns # of bytes written, or -1 for error
- */
-int writen(register int fd, register void *ptr, register int nbytes)
-{
-
-  int nleft, nwritten;
-
-  nleft = nbytes;
-  while (nleft > 0) {
-    nwritten = write(fd, ptr, nleft);
-    if (nwritten <= 0)
-      return(nwritten); /* error */
-
-    nleft -= nwritten;
-    (char*)ptr += nwritten;
-  }
-  return(nbytes - nleft);
-} /* writen */
-
 /*
  * function: ftiheader_read
  *
@@ -2315,14 +2325,14 @@ int ftiheader_read(int fd, struct ftiheader *ihead)
   struct ftmap_ifname *ftmin;
   struct ftmap_ifalias *ftmia;
   int n, ret, len_read, len_buf, off, flip, left;
-  u_int32 ip;
-  u_int16 entries, ifIndex, *ifIndex_list;
-  u_int32 head_off_d;
+  uint32_t ip;
+  uint16_t entries, ifIndex, *ifIndex_list;
+  uint32_t head_off_d;
   char *dp, *c, *enc_buf;
 
   ret = -1; 
   enc_buf = (char*)0L;
-  ifIndex_list = (u_int16*)0L;
+  ifIndex_list = (uint16_t*)0L;
   bzero(ihead, sizeof (struct ftiheader));
 
   /* read the stream header version area */
@@ -2680,7 +2690,7 @@ int ftiheader_read(int fd, struct ftiheader *ihead)
           if (flip) SWAPINT32(entries);
           c = tlv.v+6 + (entries*2);
 
-          if (!(ifIndex_list = (u_int16*)malloc(entries*2))) {
+          if (!(ifIndex_list = (uint16_t*)malloc(entries*2))) {
             fterr_warn("malloc()");
             goto ftiheader_read_out;
           }
@@ -2694,7 +2704,7 @@ int ftiheader_read(int fd, struct ftiheader *ihead)
           }
 
           free(ifIndex_list);
-          ifIndex_list = (u_int16*)0L;
+          ifIndex_list = (uint16_t*)0L;
 
           /* and link it in */
           FT_LIST_INSERT_HEAD(&ihead->ftmap->ifalias, ftmia, chain);
@@ -2789,39 +2799,14 @@ int ftio_check_generic5(struct ftio *ftio)
  *
  * returns: struct fttime
  */
-struct fttime ftltime(u_int32 sys, u_int32 secs, u_int32 nsecs, u_int32 t)
+struct fttime ftltime(uint32_t sys, uint32_t secs, uint32_t nsecs, uint32_t t)
 {
 
-  u_int32 sys_s, sys_m;
-  struct fttime ftt;
-
-  /* sysUpTime is in milliseconds, convert to seconds/milliseconds */
-  sys_s = sys / 1000;
-  sys_m = sys % 1000;
-
-  /* unix seconds/nanoseconds to seconds/milliseconds */
-  ftt.secs = secs;
-  ftt.msecs = nsecs / 1000000L;
-
-  /* subtract sysUpTime from unix seconds */
-  ftt.secs -= sys_s;
-
-  /* borrow a second? */
-  if (sys_m > ftt.msecs) {
-    -- ftt.secs;
-    ftt.msecs += 1000;
-  }
-  ftt.msecs -= sys_m;
-
-  /* add offset which is in milliseconds */
-  ftt.secs += t / 1000;
-  ftt.msecs += t % 1000;
-
-  /* fix if milliseconds >= 1000 */
-  if (ftt.msecs >= 1000) {
-    ftt.msecs -= 1000;
-    ftt.secs += 1;
-  }
+  const uint64_t real_t = secs * (uint64_t) 1000 + nsecs / 1000000 - sys + t;
+  const struct fttime ftt = {
+    .secs = real_t / 1000,
+    .msecs = real_t % 1000
+  };
 
   return ftt;
 
@@ -2849,7 +2834,7 @@ void ftset_init(struct ftset *ftset, int z_level)
 
 } /* ftset_init */
 
-int ftio_map_load(struct ftio *ftio, char *fname, u_int32 ip)
+int ftio_map_load(struct ftio *ftio, char *fname, uint32_t ip)
 {
 
   /* load the map */
@@ -2864,11 +2849,11 @@ int ftio_map_load(struct ftio *ftio, char *fname, u_int32 ip)
 
 } /* ftio_map_load */
 
-int ftio_interrupt(struct ftio *ftio, u_int32 fields)
+int ftio_interrupt(struct ftio *ftio, uint32_t fields)
 {
   struct ftmap_ifname *ftmin;
   struct ftmap_ifalias *ftmia;
-  u_int32 offset, oflag;
+  uint32_t offset, oflag;
   char *enc_buf, *rec_buf;
   int len, n, ret, flip;
 
@@ -2931,7 +2916,7 @@ int ftio_interrupt(struct ftio *ftio, u_int32 fields)
 
   if (ftio->fth.fields & FT_FIELD_INTERRUPT) {
     if ((n = fttlv_enc_uint8(enc_buf+offset, len-offset,
-      flip, FT_TLV_INTERRUPT, (u_int8)0)) < 0)
+      flip, FT_TLV_INTERRUPT, (uint8_t)0)) < 0)
       goto ftio_interrupt_out;
     else
       offset += n;
@@ -2980,7 +2965,7 @@ ftio_interrupt_out:
  * returns: 0  ok
  *          != fail - a field required is not available.
  */
-int ftio_check_xfield(struct ftio *ftio, u_int64 xfield_need)
+int ftio_check_xfield(struct ftio *ftio, uint64_t xfield_need)
 {
 
   if ((xfield_need & ftio->xfield) != xfield_need)
