@@ -29,6 +29,8 @@
 #include "ftconfig.h"
 #include "ftlib.h"
 
+#include "radix.h"
+
 #include <sys/time.h>
 #include <sys/types.h>
 #include <sys/uio.h>
@@ -59,7 +61,7 @@
 #endif
 
 extern int max_keylen;
-extern u_int32 mask_lookup[];
+extern uint32_t mask_lookup[];
 
 static struct radix_node_head *rhead;
 
@@ -69,7 +71,8 @@ struct line_parser {
   struct fttag_def_term *cur_def_term;
   int state, type;
   int lineno;
-  char *buf, *fname;
+  char *buf;
+  const char *fname;
 };
 
 #define FT_TAG_OR_SRCDST (FT_TAG_OR_SRC_TAG|FT_TAG_OR_DST_TAG)
@@ -88,49 +91,49 @@ static int resolve_actions(struct fttag *fttag);
   
 static int walk_free(struct radix_node *rn, struct walkarg *UNUSED);
 
-static inline void eval_match_src_as(struct fttag_action *fta, 
+static void eval_match_src_as(struct fttag_action *fta, 
   struct fts3rec_v1005 *rec);
-static inline void eval_match_dst_as(struct fttag_action *fta, 
+static void eval_match_dst_as(struct fttag_action *fta, 
   struct fts3rec_v1005 *rec);
-static inline void eval_match_src_prefix(struct fttag_action *fta, 
+static void eval_match_src_prefix(struct fttag_action *fta, 
   struct fts3rec_v1005 *rec);
-static inline void eval_match_dst_prefix(struct fttag_action *fta, 
+static void eval_match_dst_prefix(struct fttag_action *fta, 
   struct fts3rec_v1005 *rec);
-static inline void eval_match_nexthop(struct fttag_action *fta, 
+static void eval_match_nexthop(struct fttag_action *fta, 
   struct fts3rec_v1005 *rec);
-static inline void eval_match_as(struct fttag_action *fta, 
+static void eval_match_as(struct fttag_action *fta, 
   struct fts3rec_v1005 *rec);
-static inline void eval_match_prefix(struct fttag_action *fta, 
+static void eval_match_prefix(struct fttag_action *fta, 
   struct fts3rec_v1005 *rec);
-static inline void eval_match_tcp_src_port(struct fttag_action *fta, 
+static void eval_match_tcp_src_port(struct fttag_action *fta, 
   struct fts3rec_v1005 *rec);
-static inline void eval_match_tcp_dst_port(struct fttag_action *fta, 
+static void eval_match_tcp_dst_port(struct fttag_action *fta, 
   struct fts3rec_v1005 *rec);
-static inline void eval_match_tcp_port(struct fttag_action *fta, 
+static void eval_match_tcp_port(struct fttag_action *fta, 
   struct fts3rec_v1005 *rec);
-static inline void eval_match_udp_src_port(struct fttag_action *fta, 
+static void eval_match_udp_src_port(struct fttag_action *fta, 
   struct fts3rec_v1005 *rec);
-static inline void eval_match_udp_dst_port(struct fttag_action *fta, 
+static void eval_match_udp_dst_port(struct fttag_action *fta, 
   struct fts3rec_v1005 *rec);
-static inline void eval_match_udp_port(struct fttag_action *fta, 
+static void eval_match_udp_port(struct fttag_action *fta, 
   struct fts3rec_v1005 *rec);
-static inline void eval_match_tos(struct fttag_action *fta, 
+static void eval_match_tos(struct fttag_action *fta, 
   struct fts3rec_v1005 *rec);
-static inline void eval_match_any(struct fttag_action *fta, 
+static void eval_match_any(struct fttag_action *fta, 
   struct fts3rec_v1005 *rec);
-static inline void eval_match_in_interface(struct fttag_action *fta, 
+static void eval_match_in_interface(struct fttag_action *fta, 
   struct fts3rec_v1005 *rec);
-static inline void eval_match_out_interface(struct fttag_action *fta, 
+static void eval_match_out_interface(struct fttag_action *fta, 
   struct fts3rec_v1005 *rec);
-static inline void eval_match_interface(struct fttag_action *fta, 
+static void eval_match_interface(struct fttag_action *fta, 
   struct fts3rec_v1005 *rec);
-static inline void eval_match_exporter(struct fttag_action *fta, 
+static void eval_match_exporter(struct fttag_action *fta, 
   struct fts3rec_v1005 *rec);
-static inline void eval_match_src_ip(struct fttag_action *fta, 
+static void eval_match_src_ip(struct fttag_action *fta, 
   struct fts3rec_v1005 *rec);
-static inline void eval_match_dst_ip(struct fttag_action *fta, 
+static void eval_match_dst_ip(struct fttag_action *fta, 
   struct fts3rec_v1005 *rec);
-static inline void eval_match_ip(struct fttag_action *fta, 
+static void eval_match_ip(struct fttag_action *fta, 
   struct fts3rec_v1005 *rec);
 
 #define PARSE_STATE_ACTION          0x1
@@ -194,6 +197,68 @@ static struct jump pjump[] = {{"tag-action", 0, parse_action},
  *
  */
 
+struct fttag_prefix_look {
+  struct radix_node rt_nodes[2]; /* radix tree glue */
+  struct radix_sockaddr_in addr;
+  uint8_t masklen;
+  uint16_t set_flags;
+  uint32_t src_tag;
+  uint32_t dst_tag;
+};
+
+struct fttag_as_look {
+  uint16_t set_flags_lookup[65536];
+  uint32_t src_tag_lookup[65536];
+  uint32_t dst_tag_lookup[65536];
+};
+
+struct fttag_port_look {
+  uint16_t set_flags_lookup[65536];
+  uint32_t src_tag_lookup[65536];
+  uint32_t dst_tag_lookup[65536];
+};
+
+struct fttag_tos_look {
+  uint16_t set_flags_lookup[256];
+  uint32_t src_tag_lookup[256];
+  uint32_t dst_tag_lookup[256];
+};
+
+struct fttag_interface_look {
+  uint16_t set_flags_lookup[65536];
+  uint32_t src_tag_lookup[65536];
+  uint32_t dst_tag_lookup[65536];
+};
+
+struct fttag_any_look {
+  uint16_t set_flags;
+  uint32_t src_tag;
+  uint32_t dst_tag;
+};
+
+struct fttag_next_hop_look {
+  FT_SLIST_ENTRY(fttag_next_hop_look) chain;
+  uint32_t addr; /* key */
+  uint16_t set_flags;
+  uint32_t src_tag;
+  uint32_t dst_tag;
+};
+
+struct fttag_exporter_look {
+  FT_SLIST_ENTRY(fttag_exporter_look) chain;
+  uint32_t addr; /* key */
+  uint16_t set_flags;
+  uint32_t src_tag;
+  uint32_t dst_tag;
+};
+
+struct fttag_ip_look {
+  FT_SLIST_ENTRY(fttag_ip_look) chain;
+  uint32_t addr; /* key */
+  uint16_t set_flags;
+  uint32_t src_tag;
+  uint32_t dst_tag;
+};
 
 /*
  * function: fttag_load
@@ -203,13 +268,13 @@ static struct jump pjump[] = {{"tag-action", 0, parse_action},
  * returns: 0  ok
  *          <0 fail
  */
-int fttag_load(struct fttag *fttag, struct ftvar *ftvar, char *fname)
+int fttag_load(struct fttag *fttag, struct ftvar *ftvar, const char *fname)
 {
   static int rn_init_called;
   struct stat sb;
   struct jump *jmp;
   struct line_parser lp;
-  int fd, ret, found;
+  int fd, ret, found = 0;
   char *buf, *buf2, *c;
   char sbuf[FT_LP_MAXLINE];
 
@@ -362,7 +427,7 @@ load_tags_out:
  * returns : pointer to fttag_def_lookup or null if not found or error.
  *
  */
-struct fttag_def *fttag_def_find(struct fttag *fttag, char *name)
+struct fttag_def *fttag_def_find(struct fttag *fttag, const char *name)
 {
   struct fttag_def *ftd;
 
@@ -676,9 +741,9 @@ int parse_action_match(struct line_parser *lp, struct fttag *fttag)
   struct fttag_any_look *any_look;
   struct ip_prefix ipp;
   struct radix_node_head *rhead;
-  u_int32 tag, hash, ipaddr;
-  u_int16 as, port, interface;
-  u_int8 tos;
+  uint32_t tag, hash, ipaddr;
+  uint16_t as, port, interface;
+  uint8_t tos;
   int sflag, new, tflag2, tmpflag, tflag;
   char *c, *match;
 
@@ -1477,7 +1542,7 @@ int resolve_actions(struct fttag *fttag)
   struct fttag_def_term *ftdt;
   struct fttag_def_term_actions *ftdta;
   struct fttag_action *fta;
-  int i, found;
+  int i, found = 0;
 
   /* foreach definition */
   FT_SLIST_FOREACH(ftd, &fttag->defs, chain) {
@@ -1625,7 +1690,7 @@ void fttag_free(struct fttag *fttag)
  *
  * returns 0
  */
-inline int fttag_def_eval(struct fttag_def *ftd,
+int fttag_def_eval(struct fttag_def *ftd,
   struct fts3rec_v1005 *rec)
 {
   struct fttag_def_term *ftdt;
@@ -1664,11 +1729,11 @@ inline int fttag_def_eval(struct fttag_def *ftd,
 
 } /* fttag_def_eval */
 
-inline void eval_match_src_as(struct fttag_action *fta,
+static void eval_match_src_as(struct fttag_action *fta,
   struct fts3rec_v1005 *rec)
 {
   struct fttag_as_look *as_look;
-  u_int16 set_tmp;
+  uint16_t set_tmp;
  
   as_look = fta->look;
  
@@ -1686,11 +1751,11 @@ inline void eval_match_src_as(struct fttag_action *fta,
 
 } /* eval_match_src_as */
 
-inline void eval_match_dst_as(struct fttag_action *fta,
+static void eval_match_dst_as(struct fttag_action *fta,
   struct fts3rec_v1005 *rec)
 {
   struct fttag_as_look *as_look;
-  u_int16 set_tmp;
+  uint16_t set_tmp;
  
   as_look = fta->look;
  
@@ -1708,13 +1773,13 @@ inline void eval_match_dst_as(struct fttag_action *fta,
 
 } /* eval_match_dst_as */
 
-inline void eval_match_src_prefix(struct fttag_action *fta,
+static void eval_match_src_prefix(struct fttag_action *fta,
   struct fts3rec_v1005 *rec)
 {
   struct radix_sockaddr_in dst_sock;
   struct fttag_prefix_look *prefix_look;
   struct radix_node_head *rhead;
-  u_int16 set_tmp;
+  uint16_t set_tmp;
 
   rhead = fta->look;
 
@@ -1743,13 +1808,13 @@ inline void eval_match_src_prefix(struct fttag_action *fta,
 
 } /* eval_match_src_prefix */
 
-inline void eval_match_dst_prefix(struct fttag_action *fta,
+static void eval_match_dst_prefix(struct fttag_action *fta,
   struct fts3rec_v1005 *rec)
 {
   struct radix_sockaddr_in dst_sock;
   struct fttag_prefix_look *prefix_look;
   struct radix_node_head *rhead;
-  u_int16 set_tmp;
+  uint16_t set_tmp;
 
   rhead = fta->look;
 
@@ -1778,13 +1843,13 @@ inline void eval_match_dst_prefix(struct fttag_action *fta,
 
 } /* eval_match_dst_prefix */
 
-inline void eval_match_nexthop(struct fttag_action *fta,
+static void eval_match_nexthop(struct fttag_action *fta,
   struct fts3rec_v1005 *rec)
 {
   struct ftchash *ftch;
-  u_int32 hash, ipaddr;
+  uint32_t hash, ipaddr;
   struct fttag_next_hop_look *nh_look;
-  u_int16 set_tmp;
+  uint16_t set_tmp;
 
   ftch = fta->look;
   ipaddr = rec->nexthop;
@@ -1813,13 +1878,13 @@ inline void eval_match_nexthop(struct fttag_action *fta,
 
 } /* eval_match_nexthop */
 
-inline void eval_match_exporter(struct fttag_action *fta,
+static void eval_match_exporter(struct fttag_action *fta,
   struct fts3rec_v1005 *rec)
 {
   struct ftchash *ftch;
-  u_int32 hash, ipaddr;
+  uint32_t hash, ipaddr;
   struct fttag_exporter_look *exporter_look;
-  u_int16 set_tmp;
+  uint16_t set_tmp;
 
   ftch = fta->look;
   ipaddr = rec->exaddr;
@@ -1849,13 +1914,13 @@ inline void eval_match_exporter(struct fttag_action *fta,
 
 } /* eval_match_exporter */
 
-inline void eval_match_src_ip(struct fttag_action *fta,
+static void eval_match_src_ip(struct fttag_action *fta,
   struct fts3rec_v1005 *rec)
 {
   struct ftchash *ftch;
-  u_int32 hash, ipaddr;
+  uint32_t hash, ipaddr;
   struct fttag_ip_look *ip_look;
-  u_int16 set_tmp;
+  uint16_t set_tmp;
 
   ftch = fta->look;
   ipaddr = rec->srcaddr;
@@ -1885,13 +1950,13 @@ inline void eval_match_src_ip(struct fttag_action *fta,
 
 } /* eval_match_src_ip */
 
-inline void eval_match_dst_ip(struct fttag_action *fta,
+static void eval_match_dst_ip(struct fttag_action *fta,
   struct fts3rec_v1005 *rec)
 {
   struct ftchash *ftch;
-  u_int32 hash, ipaddr;
+  uint32_t hash, ipaddr;
   struct fttag_ip_look *ip_look;
-  u_int16 set_tmp;
+  uint16_t set_tmp;
 
   ftch = fta->look;
   ipaddr = rec->dstaddr;
@@ -1921,25 +1986,25 @@ inline void eval_match_dst_ip(struct fttag_action *fta,
 
 } /* eval_match_dst_ip */
 
-inline void eval_match_prefix(struct fttag_action *fta,
+static void eval_match_prefix(struct fttag_action *fta,
   struct fts3rec_v1005 *rec)
 {
   eval_match_src_prefix(fta, rec);
   eval_match_dst_prefix(fta, rec);
 } /* eval_match_prefix */
 
-inline void eval_match_as(struct fttag_action *fta,
+static void eval_match_as(struct fttag_action *fta,
   struct fts3rec_v1005 *rec)
 {
   eval_match_src_as(fta, rec);
   eval_match_dst_as(fta, rec);
 } /* eval_match_as */
 
-inline void eval_match_tcp_src_port(struct fttag_action *fta,
+static void eval_match_tcp_src_port(struct fttag_action *fta,
   struct fts3rec_v1005 *rec)
 {
   struct fttag_port_look *port_look;
-  u_int16 set_tmp;
+  uint16_t set_tmp;
  
   port_look = fta->look;
 
@@ -1961,11 +2026,11 @@ inline void eval_match_tcp_src_port(struct fttag_action *fta,
 
 } /* eval_match_tcp_src_port */
 
-inline void eval_match_tcp_dst_port(struct fttag_action *fta,
+static void eval_match_tcp_dst_port(struct fttag_action *fta,
   struct fts3rec_v1005 *rec)
 {
   struct fttag_port_look *port_look;
-  u_int16 set_tmp;
+  uint16_t set_tmp;
  
   port_look = fta->look;
 
@@ -1987,11 +2052,11 @@ inline void eval_match_tcp_dst_port(struct fttag_action *fta,
 
 } /* eval_match_tcp_dst_port */
 
-inline void eval_match_udp_src_port(struct fttag_action *fta,
+static void eval_match_udp_src_port(struct fttag_action *fta,
   struct fts3rec_v1005 *rec)
 {
   struct fttag_port_look *port_look;
-  u_int16 set_tmp;
+  uint16_t set_tmp;
  
   port_look = fta->look;
 
@@ -2013,11 +2078,11 @@ inline void eval_match_udp_src_port(struct fttag_action *fta,
 
 } /* eval_match_udp_src_port */
 
-inline void eval_match_udp_dst_port(struct fttag_action *fta,
+static void eval_match_udp_dst_port(struct fttag_action *fta,
   struct fts3rec_v1005 *rec)
 {
   struct fttag_port_look *port_look;
-  u_int16 set_tmp;
+  uint16_t set_tmp;
  
   port_look = fta->look;
 
@@ -2039,25 +2104,25 @@ inline void eval_match_udp_dst_port(struct fttag_action *fta,
 
 } /* eval_match_udp_dst_port */
 
-inline void eval_match_tcp_port(struct fttag_action *fta,
+static void eval_match_tcp_port(struct fttag_action *fta,
   struct fts3rec_v1005 *rec)
 {
   eval_match_tcp_src_port(fta, rec);
   eval_match_tcp_dst_port(fta, rec);
 } /* eval_match_tcp_port */
 
-inline void eval_match_udp_port(struct fttag_action *fta,
+static void eval_match_udp_port(struct fttag_action *fta,
   struct fts3rec_v1005 *rec)
 {
   eval_match_udp_src_port(fta, rec);
   eval_match_udp_dst_port(fta, rec);
 } /* eval_match_udp_port */
 
-inline void eval_match_in_interface(struct fttag_action *fta,
+static void eval_match_in_interface(struct fttag_action *fta,
   struct fts3rec_v1005 *rec)
 {
   struct fttag_interface_look *interface_look;
-  u_int16 set_tmp;
+  uint16_t set_tmp;
  
   interface_look = fta->look;
 
@@ -2075,11 +2140,11 @@ inline void eval_match_in_interface(struct fttag_action *fta,
 
 } /* eval_match_in_interface */
 
-inline void eval_match_out_interface(struct fttag_action *fta,
+static void eval_match_out_interface(struct fttag_action *fta,
   struct fts3rec_v1005 *rec)
 {
   struct fttag_interface_look *interface_look;
-  u_int16 set_tmp;
+  uint16_t set_tmp;
  
   interface_look = fta->look;
 
@@ -2097,25 +2162,25 @@ inline void eval_match_out_interface(struct fttag_action *fta,
 
 } /* eval_match_out_interface */
 
-inline void eval_match_interface(struct fttag_action *fta,
+static void eval_match_interface(struct fttag_action *fta,
   struct fts3rec_v1005 *rec)
 {
   eval_match_in_interface(fta, rec);
   eval_match_out_interface(fta, rec);
 } /* eval_match_interface */
 
-inline void eval_match_ip(struct fttag_action *fta,
+static void eval_match_ip(struct fttag_action *fta,
   struct fts3rec_v1005 *rec)
 {
   eval_match_src_ip(fta, rec);
   eval_match_dst_ip(fta, rec);
 } /* eval_match_ip */
 
-inline void eval_match_tos(struct fttag_action *fta,
+static void eval_match_tos(struct fttag_action *fta,
   struct fts3rec_v1005 *rec)
 {
   struct fttag_tos_look *tos_look;
-  u_int16 set_tmp;
+  uint16_t set_tmp;
  
   tos_look = fta->look;
 
@@ -2133,11 +2198,11 @@ inline void eval_match_tos(struct fttag_action *fta,
 
 } /* eval_match_tos */
 
-inline void eval_match_any(struct fttag_action *fta,
+static void eval_match_any(struct fttag_action *fta,
   struct fts3rec_v1005 *rec)
 {
   struct fttag_any_look *any_look;
-  u_int16 set_tmp;
+  uint16_t set_tmp;
  
   any_look = fta->look;
 
