@@ -43,7 +43,7 @@
 /*
  * function: fttlv_enc_uint32
  *
- * encode a u_int32 TLV into buf
+ * encode a uint32_t TLV into buf
  *  buf        buffer to encode to
  *  buf_size   available bytes in buf
  *  flip       swap byte order
@@ -52,9 +52,9 @@
  *
  * returns: -1 if buffer is not large enough, else bytes used.
 */
-int fttlv_enc_uint32(void *buf, int buf_size, int flip, u_int16 t, u_int32 v)
+int fttlv_enc_uint32(void *buf, int buf_size, int flip, uint16_t t, uint32_t v)
 {
-  u_int16 len;
+  uint16_t len;
 
   if (buf_size < 8)
     return -1;
@@ -68,11 +68,11 @@ int fttlv_enc_uint32(void *buf, int buf_size, int flip, u_int16 t, u_int32 v)
   }
 
   bcopy(&t, buf, 2);
-  (char*)buf+= 2;
-
+  buf = (char*)buf + 2;
+  
   bcopy(&len, buf, 2);
-  (char*)buf+= 2;
-
+  buf = (char*)buf + 2;
+  
   bcopy(&v, buf, 4);
 
   return 8;
@@ -82,7 +82,7 @@ int fttlv_enc_uint32(void *buf, int buf_size, int flip, u_int16 t, u_int32 v)
 /*
  * function: fttlv_enc_uint16
  *
- * encode a u_int16 TLV into buf
+ * encode a uint16_t TLV into buf
  *  buf        buffer to encode to
  *  buf_size   available bytes in buf
  *  flip       swap byte order
@@ -91,9 +91,9 @@ int fttlv_enc_uint32(void *buf, int buf_size, int flip, u_int16 t, u_int32 v)
  *
  * returns: -1 if buffer is not large enough, else bytes used.
 */
-int fttlv_enc_uint16(void *buf, int buf_size, int flip, u_int16 t, u_int16 v)
+int fttlv_enc_uint16(void *buf, int buf_size, int flip, uint16_t t, uint16_t v)
 {
-  u_int16 len;
+  uint16_t len;
 
   if (buf_size < 6)
     return -1;
@@ -107,21 +107,21 @@ int fttlv_enc_uint16(void *buf, int buf_size, int flip, u_int16 t, u_int16 v)
   }
 
   bcopy(&t, buf, 2);
-  (char*)buf+= 2;
-
+  buf = (char*)buf + 2;
+  
   bcopy(&len, buf, 2);
-  (char*)buf+= 2;
-
+  buf = (char*)buf + 2;
+  
   bcopy(&v, buf, 2);
 
   return 6;
 
-} /* fttlv_enc_uint16 */
+} /* fttlv_enc_uint16_t */
 
 /*
  * function: fttlv_enc_uint8
  *
- * encode a u_int8 TLV into buf
+ * encode a uint8_t TLV into buf
  *  buf        buffer to encode to
  *  buf_size   available bytes in buf
  *  flip       swap byte order
@@ -130,9 +130,9 @@ int fttlv_enc_uint16(void *buf, int buf_size, int flip, u_int16 t, u_int16 v)
  *
  * returns: -1 if buffer is not large enough, else bytes used.
 */
-int fttlv_enc_uint8(void *buf, int buf_size, int flip, u_int16 t, u_int8 v)
+int fttlv_enc_uint8(void *buf, int buf_size, int flip, uint16_t t, uint8_t v)
 {
-  u_int16 len;
+  uint16_t len;
 
   if (buf_size < 5)
     return -1;
@@ -145,11 +145,11 @@ int fttlv_enc_uint8(void *buf, int buf_size, int flip, u_int16 t, u_int8 v)
   }
 
   bcopy(&t, buf, 2);
-  (char*)buf+= 2;
+  buf = (char*)buf + 2;
 
   bcopy(&len, buf, 2);
-  (char*)buf+= 2;
-
+  buf = (char*)buf + 2;
+  
   bcopy(&v, buf, 1);
 
   return 5;
@@ -168,9 +168,9 @@ int fttlv_enc_uint8(void *buf, int buf_size, int flip, u_int16 t, u_int8 v)
  *
  * returns: -1 if buffer is not large enough, else bytes used.
 */
-int fttlv_enc_str(void *buf, int buf_size, int flip, u_int16 t, char *v)
+int fttlv_enc_str(void *buf, int buf_size, int flip, uint16_t t, char *v)
 {
-  u_int16 len, len2;
+  uint16_t len, len2;
 
   len = len2 = strlen(v)+1;
 
@@ -183,10 +183,10 @@ int fttlv_enc_str(void *buf, int buf_size, int flip, u_int16 t, char *v)
   }
 
   bcopy(&t, buf, 2);
-  (char*)buf+= 2;
+  buf = (char*)buf + 2;
 
   bcopy(&len, buf, 2);
-  (char*)buf+= 2;
+  buf = (char*)buf + 2;
 
   bcopy(v, buf, len);
 
@@ -209,10 +209,10 @@ int fttlv_enc_str(void *buf, int buf_size, int flip, u_int16 t, char *v)
  *
  * returns: -1 if buffer is not large enough, else bytes used.
  */
-int fttlv_enc_ifname(void *buf, int buf_size, int flip, u_int16 t,
-  u_int32 ip, u_int16 ifIndex, char *name)
+int fttlv_enc_ifname(void *buf, int buf_size, int flip, uint16_t t,
+  uint32_t ip, uint16_t ifIndex, char *name)
 {
-  u_int16 len, len2;
+  uint16_t len, len2;
   int n;
 
   n = strlen(name)+1;
@@ -230,17 +230,17 @@ int fttlv_enc_ifname(void *buf, int buf_size, int flip, u_int16 t,
     return -1;
 
   bcopy(&t, buf, 2);
-  (char*)buf+= 2;
-
+  buf = (char*)buf + 2;
+  
   bcopy(&len, buf, 2);
-  (char*)buf+= 2;
-
+  buf = (char*)buf + 2;
+  
   bcopy(&ip, buf, 4);
-  (char*)buf += 4;
-
+  buf = (char*)buf + 2;
+  
   bcopy(&ifIndex, buf, 2);
-  (char*)buf += 2;
-
+  buf = (char*)buf + 2;
+  
   bcopy(name, buf, n);
 
   return 4+len2;
@@ -262,10 +262,10 @@ int fttlv_enc_ifname(void *buf, int buf_size, int flip, u_int16 t,
  *
  * returns: -1 if buffer is not large enough, else bytes used.
  */
-int fttlv_enc_ifalias(void *buf, int buf_size, int flip, u_int16 t,
-  u_int32 ip, u_int16 *ifIndex_list, u_int16 entries, char *name)
+int fttlv_enc_ifalias(void *buf, int buf_size, int flip, uint16_t t,
+  uint32_t ip, uint16_t *ifIndex_list, uint16_t entries, char *name)
 {
-  u_int16 len, len2;
+  uint16_t len, len2;
   int n,i,esize;
 
   n = strlen(name)+1;
@@ -287,20 +287,20 @@ int fttlv_enc_ifalias(void *buf, int buf_size, int flip, u_int16 t,
   }
 
   bcopy(&t, buf, 2);
-  (char*)buf+= 2;
-
+  buf = (char*)buf + 2;
+  
   bcopy(&len, buf, 2);
-  (char*)buf+= 2;
-
+  buf = (char*)buf + 2;
+	  
   bcopy(&ip, buf, 4);
-  (char*)buf += 4;
+  buf = (char*)buf + 2;
 
   bcopy(&entries, buf, 2);
-  (char*)buf += 2;
+  buf = (char*)buf + 2;
 
   bcopy(ifIndex_list, buf, esize);
-  (char*)buf += esize;
-
+  buf = (char*)buf + esize;
+  
   bcopy(name, buf, n);
 
   return 4+len2;
