@@ -26,9 +26,13 @@
  *      $Id: support.c,v 1.35 2003/02/13 02:38:43 maf Exp $
  */
 
-#include "ftconfig.h"
+#include "ftinclude.h"
 #include "ftlib.h"
 
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/socket.h>
@@ -43,13 +47,6 @@
 #include <time.h>
 #include <fcntl.h>
 
-#if HAVE_STRINGS_H
- #include <strings.h>
-#endif
-#if HAVE_STRING_H
-  #include <string.h>
-#endif
-
 #if !HAVE_STRSEP
   char    *strsep (char **, const char *);
 #endif
@@ -66,7 +63,7 @@
  *  248.0.0.0 252.0.0.0 254.0.0.0 255.0.0.0
  *
  */
-u_int32 mask_lookup[] = { 0xffffffff,
+uint32_t mask_lookup[] = { 0xffffffff,
      0x80000000, 0xc0000000, 0xe0000000, 0xf0000000,
      0xf8000000, 0xfc000000, 0xfe000000, 0xff000000,
      0xff800000, 0xffc00000, 0xffe00000, 0xfff00000,
@@ -82,7 +79,7 @@ u_int32 mask_lookup[] = { 0xffffffff,
  * returns the 32 bit network mask given a length
  *
 */
-u_int32 ipv4_len2mask(u_int8 len)
+uint32_t ipv4_len2mask(uint8_t len)
 {
   return mask_lookup[(len > 32) ? 0 : len];
 }
@@ -280,13 +277,13 @@ struct ip_prefix scan_ip_prefix(char *input)
  *  left shift any partial dotted quads, ie 10 is 0x0a000000 not 0x0a
  *  so scan_ip_prefix() works for standard prefix notation, ie 10/8
  */
-u_long scan_ip(char *s)
+uint32_t scan_ip(char *s)
 {
   struct hostent *he;
   struct in_addr *ina;
-  u_long addr = 0;
-  u_int n;
-  int dns, shift;
+  uint32_t addr = 0;
+  unsigned int n;
+  int dns, shift = 0;
   char *t;
 
   /* if there is anything ascii in here, this may be a hostname */
@@ -305,7 +302,7 @@ u_long scan_ip(char *s)
     if (he->h_addrtype != AF_INET)
       goto numeric;
 
-    if (he->h_length != sizeof (u_int32))
+    if (he->h_length != sizeof (uint32_t))
       goto numeric;
 
     ina = (struct in_addr*)*he->h_addr_list;
@@ -313,8 +310,6 @@ u_long scan_ip(char *s)
 
   } /* dns */
 
-  shift = 0;
-
 numeric:
   while (1) {
 
@@ -381,9 +376,9 @@ void print_3float2(float f)
 } /* print_3float */
 
 /* adapted from dd */
-int64 scan_size(char *val)
+int64_t scan_size(char *val)
 {
-  u_int64 num, t;
+  uint64_t num, t;
   char *expr;
 
   if ((num = strtoul(val, &expr, 0)) == ULONG_MAX)
@@ -429,7 +424,7 @@ int64 scan_size(char *val)
 
 erange: 
 
-  return (int64)-1;
+  return (int64_t)-1;
 
 } /* scan_size */
 
@@ -477,7 +472,7 @@ void *mysignal(int signo, void *func)
 
 
 
-int unlink_pidfile(int pid, char *file, u_int16 port)
+int unlink_pidfile(int pid, char *file, uint16_t port)
 {
   char *c;
   int ret;
@@ -497,7 +492,7 @@ int unlink_pidfile(int pid, char *file, u_int16 port)
 } /* unlink_pidfile */
  
 
-int write_pidfile(int pid, char *file, u_int16 port)
+int write_pidfile(int pid, char *file, uint16_t port)
 {
   int fd, len;
   char str[16], *c;
@@ -625,7 +620,7 @@ int bigsockbuf(int fd, int dir, int size)
 */
 int mkpath(const char *path, mode_t mode)
 {
-  char *c, *cs, *c2, *p, *p2;
+  char *c, *cs = NULL, *c2 = NULL, *p, *p2;
   int len, ret, done, nodir;
  
   len = strlen(path);
@@ -713,14 +708,14 @@ mkpath_out:
  */
 int udp_cksum(struct ip *ip, struct udphdr *up, int len)
 {
-  u_int16 *word;
+  uint16_t *word;
   int sum;
   
-  word = (u_int16*)&ip->ip_src.s_addr;
+  word = (uint16_t*)&ip->ip_src.s_addr;
   sum = *word++;
   sum += *word;
 
-  word = (u_int16*)&ip->ip_dst.s_addr;
+  word = (uint16_t*)&ip->ip_dst.s_addr;
   sum += *word++;
   sum += *word;
 
@@ -728,7 +723,7 @@ int udp_cksum(struct ip *ip, struct udphdr *up, int len)
 
   sum += IPPROTO_UDP<<8;
 
-  word = (u_short*)up;
+  word = (unsigned short*)up;
   sum += *word++;
   sum += *word++;
   sum += *word++;
