@@ -55,8 +55,6 @@
   #include <string.h>
 #endif
 
-#include "ftbuild.h"
-
 #ifdef HAVE_LIBWRAP
 #include <tcpd.h>
 #endif /* HAVE_LIBWRAP */
@@ -101,10 +99,10 @@ struct file {
   time_t time;
   struct ftver ftv;
   off_t nbytes;
-  u_int32 hdr_nflows;
-  u_int32 hdr_flows_corrupt;
-  u_int32 hdr_flows_lost;
-  u_int32 hdr_flows_reset;
+  uint32_t hdr_nflows;
+  uint32_t hdr_flows_corrupt;
+  uint32_t hdr_flows_lost;
+  uint32_t hdr_flows_reset;
 };
 
 int debug;
@@ -163,17 +161,22 @@ char **argv;
   char work_dir[MAXPATHLEN+1], post_rotate_exec[MAXPATHLEN+1];
   int i, n, tmp_len, enable_unlink, offset, detach, nest, one, max_fd;
   unsigned int v1, v2;
-  u_int32 hash;
+  uint32_t hash;
   char fmt_src_ip[32], fmt_dst_ip[32], fmt_dst_port[32];
   char xl_rec[FT_IO_MAXREC], *out_rec;
-  char *tag_fname, *tag_active;
-  char *filter_fname, *filter_active;
-  char *xlate_fname, *xlate_active;
+  const char *tag_fname, *tag_active;
+  const char *filter_fname, *filter_active;
+  const char *xlate_fname, *xlate_active;
   int stat_interval, stat_next, child_status;
   int v_flag;
   int preserve_umask;
+#ifdef IP_RECVDSTADDR
+#ifdef CMSG_DATA
+  struct cmsghdr *cmsg;
+#endif
+#endif
 
-  time_startup = time((time_t)0L);
+  time_startup = time(NULL);
 
   bzero (&rot, sizeof rot);
   bzero (&cap_file, sizeof cap_file);
@@ -350,7 +353,7 @@ char **argv;
       ftv.set = 1;
       break;
 
-    case 'i': /* preserve inherited umask */
+    case 'u': /* preserve inherited umask */
       preserve_umask = 1;
       break;
 
@@ -443,9 +446,7 @@ char **argv;
     if ((pid = fork()) == -1) {
       fterr_err(1, "fork()");
     } else if (pid) {
-      if (pidfile)
-        write_pidfile(pid, pidfile, ftnet.dst_port);
-      exit (0); /* parent */
+         exit (0); /* parent */
     }
 
     if (!preserve_umask)
@@ -500,7 +501,7 @@ char **argv;
 
   /* run the ager once now */
   if (fte.expiring)
-    if (ftfile_expire(&fte, enable_unlink, (u_int32)0))
+    if (ftfile_expire(&fte, enable_unlink, (uint32_t)0))
       fterr_errx(1, "ftfile_export(): failed");
 
   /* get hostname */
@@ -613,6 +614,10 @@ mcast_done:
   if (!(ftch = ftchash_new(256, sizeof (struct ftchash_rec_exp), 12, 1)))
     fterr_errx(1, "ftchash_new(): failed");
 
+  /* If we bind to the socket we are running and can write the pidfile */
+  if (pidfile)
+       write_pidfile(getpid(), pidfile, ftnet.dst_port);
+
   /* init msg block */
   ftnet.iov[0].iov_len = sizeof ftpdu.buf;
   ftnet.iov[0].iov_base = (char*)&ftpdu.buf;
@@ -621,7 +626,12 @@ mcast_done:
   ftnet.msg.msg_name = &ftnet.rem_addr;
   ftnet.msg.msg_namelen = sizeof ftnet.rem_addr;
   ftnet.msg.msg_control = &ftnet.msgip;
+
+#ifdef CMSG_DATA
+  ftnet.msg.msg_controllen = CMSG_LEN(sizeof(struct sockaddr_storage));
+#else
   ftnet.msg.msg_controllen = sizeof ftnet.msgip;
+#endif
 
   while (1) {
 
@@ -853,12 +863,24 @@ restart_recvmsg:
 
 #ifdef IP_RECVDSTADDR
       /* got destination IP back? */
+#ifdef CMSG_DATA
+      for (cmsg = CMSG_FIRSTHDR(&ftnet.msg); cmsg != NULL;
+          cmsg = CMSG_NXTHDR(&ftnet.msg, cmsg)) {
+              if (cmsg->cmsg_level == IPPROTO_IP &&
+                  cmsg->cmsg_type == IP_RECVDSTADDR) {
+                      memcpy(&ftnet.loc_addr.sin_addr.s_addr,
+                          CMSG_DATA(cmsg), sizeof(struct in_addr));
+                      break;
+              }
+      }
+#else
       if ((ftnet.msgip.hdr.cmsg_level == IPPROTO_IP) &&
           (ftnet.msgip.hdr.cmsg_type == IP_RECVDSTADDR)) {
           ftnet.loc_addr.sin_addr.s_addr = ftnet.msgip.ip.s_addr;
       } else {
         ftnet.loc_addr.sin_addr.s_addr = 0;
       }
+#endif /* CMSG_DATA */
 #else
 #ifdef IP_PKTINFO
       if ((ftnet.msgip.hdr.cmsg_level == IPPROTO_IP) &&
@@ -998,7 +1020,7 @@ skip_pdu_decode:
         fterr_errx(1, "calc_rotate(): failed");
 
       /* remember when file was created */
-      cap_file.time = (u_int32)tt_now;
+      cap_file.time = (uint32_t)tt_now;
 
       /* remember the version encoded in the filename */
       bcopy(&ftv, &cap_file.ftv, sizeof cap_file.ftv);
@@ -1192,7 +1214,7 @@ skip_pdu_decode:
             
       if (cap_file.fd != -1) {
 
-        ftio_set_cap_time(&ftio, cap_file.time, (u_int32)tt_now);
+        ftio_set_cap_time(&ftio, cap_file.time, (uint32_t)tt_now);
         ftio_set_corrupt(&ftio, cap_file.hdr_flows_corrupt);
         ftio_set_lost(&ftio, cap_file.hdr_flows_lost);
         ftio_set_reset(&ftio, cap_file.hdr_flows_reset);
@@ -1425,7 +1447,6 @@ void usage(void) {
   fprintf(stderr, "Signals:\n");
   fprintf(stderr, "   SIGHUP  - close and rotate current file\n");
   fprintf(stderr, "   SIGQUIT - close current file and exit\n");
-fprintf(stderr, "\n%s version %s: built by %s\n", PACKAGE, VERSION, FT_PROG_BUILD);
 
 } /* usage */ 
 
