@@ -48,7 +48,6 @@
   #include <string.h>
 #endif
 
-#include "ftbuild.h"
 
 int debug;
 int done;
@@ -71,9 +70,9 @@ int main(int argc, char **argv)
   char *fname, *out_fname;
   char *rec;
   u_long total_bytes;
-  u_int32 total_flows, lost_flows, corrupt_flows, total_streams;
-  u_int32 time_start, time_end, time_tmp1, time_tmp2, time_delta;
-  u_int32 time_low, time_high;
+  uint32_t total_flows, lost_flows, corrupt_flows, total_streams;
+  uint32_t time_start, time_end, time_tmp1, time_tmp2, time_delta;
+  uint32_t time_low, time_high;
 
   /* init fterr */
   fterr_setid(argv[0]);
@@ -314,6 +313,8 @@ skip1:
     }
   }
 
+  /* FIXME: this is a horrible copy&paste shit... */
+
   /* preload headers */
   if (preload) {
 
@@ -412,6 +413,29 @@ skip1:
 
         /* total flows */
         total_flows += ftio_get_flows_count(&ftio_in);
+        if (ftio_get_hostname(&ftio_in))
+          ftio_set_cap_hostname(&ftio_out, ftio_get_hostname(&ftio_in));
+        if (ftio_get_comment(&ftio_in))
+          ftio_set_comment(&ftio_out, ftio_get_comment(&ftio_in));
+        if (ftio_in.fth.fields & FT_FIELD_SEQ_RESET)
+          ftio_set_reset(&ftio_out, ftio_in.fth.seq_reset);
+
+#define COPY_IF_EXISTS(BITS, FIELD) \
+        do { \
+          if (ftio_in.fth.fields & BITS) { \
+            ftio_out.fth.fields |= BITS; \
+            ftio_out.fth.FIELD = ftio_in.fth.FIELD; \
+          } \
+        } while(0)
+
+        COPY_IF_EXISTS(FT_FIELD_FLOW_MISORDERED, flows_misordered);
+        COPY_IF_EXISTS(FT_FIELD_VENDOR, vendor);
+        COPY_IF_EXISTS(FT_FIELD_EXPORTER_IP, exporter_ip);
+        COPY_IF_EXISTS(FT_FIELD_AGG_METHOD, agg_method);
+        COPY_IF_EXISTS(FT_FIELD_AGG_VER, agg_version);
+        COPY_IF_EXISTS(FT_FIELD_ROT_SCHEDULE, rotation);
+
+#undef COPY_IF_EXISTS
 
 skip_file:
         if (debug > 5)
@@ -626,7 +650,6 @@ void usage(void) {
   fprintf(stderr, "       [-o filename] [-t start_time] [-T end_time] [-z z_level]\n");
   fprintf(stderr, "       file|directory ...");
   fprintf(stderr, "\n");
-  fprintf(stderr, "\n%s version %s: built by %s\n", PACKAGE, VERSION, FT_PROG_BUILD);
 
 
 } /* usage */
