@@ -51,25 +51,25 @@
 
 #include <mysql.h>
 
-#define DB_DEFAULT_DBHOST "localhost"
-#define DB_DEFAULT_DBNAME "netflow"
-#define DB_DEFAULT_DBPORT 3306
-#define DB_DEFAULT_DBTABLE "raw"
-#define DB_DEFAULT_DBUSER "netflow"
-#define DB_DEFAULT_DBPWD "netflow"
+#define MYSQL_DEFAULT_DBHOST "localhost"
+#define MYSQL_DEFAULT_DBNAME "netflow"
+#define MYSQL_DEFAULT_DBPORT 3306
+#define MYSQL_DEFAULT_DBTABLE "raw"
+#define MYSQL_DEFAULT_DBUSER "netflow"
+#define MYSQL_DEFAULT_DBPWD "netflow"
 
 #endif /* MYSQL */
 
-#ifdef HAVE_PGSQL
+#ifdef HAVE_POSTGRESQL
 
 #include <libpq-fe.h>
 
-#define DB_DEFAULT_DBHOST "localhost"
-#define DB_DEFAULT_DBNAME "netflow"
-#define DB_DEFAULT_DBPORT "5432"
-#define DB_DEFAULT_DBTABLE "raw"
-#define DB_DEFAULT_DBUSER "netflow"
-#define DB_DEFAULT_DBPWD "netflow"
+#define POSTGRESQL_DEFAULT_DBHOST "localhost"
+#define POSTGRESQL_DEFAULT_DBNAME "netflow"
+#define POSTGRESQL_DEFAULT_DBPORT "5432"
+#define POSTGRESQL_DEFAULT_DBTABLE "raw"
+#define POSTGRESQL_DEFAULT_DBUSER "netflow"
+#define POSTGRESQL_DEFAULT_DBPWD "netflow"
 
 #endif /* PGSQL*/
 
@@ -77,7 +77,6 @@
   #define strtoull strtoul
 #endif /* HAVE_LL_STRTOULL */
 
-#include "ftbuild.h"
 #include "pcap.h"
 #include "cflowd.h"
 
@@ -87,8 +86,8 @@
 
 struct options {
   char dbaseURI[256];
-  u_int32 cflowd_mask;
-  u_int64 ft_mask;
+  uint32_t cflowd_mask;
+  uint64_t ft_mask;
   u_long records;
 };
 
@@ -103,11 +102,11 @@ int format3(struct ftio *ftio, struct options *opt);
 int format4(struct ftio *ftio, struct options *opt);
 int format5(struct ftio *ftio, struct options *opt);
 
-int ftxfield_tocflow(u_int64 xfields, u_int32 *cfmask);
+int ftxfield_tocflow(uint64_t xfields, uint32_t *cfmask);
 
 int fmt_xfields_val(char *fmt_buf, char *rec, struct fts3rec_offsets *fo,
-  u_int64 xfields, int quote);
-int fmt_xfields_type(char *buf, u_int64 xfield);
+  uint64_t xfields, int quote);
+int fmt_xfields_type(char *buf, uint64_t xfield);
 
 void usage(void);
 
@@ -221,9 +220,9 @@ int format0(struct ftio *ftio, struct options *opt)
   struct ftver ftv;
   struct fttime ftt;
   char *rec;
-  u_int32 ui32, index, sysUpTime, unix_secs, unix_nsecs, First, Last;
-  u_int16 ui16;
-  u_int8 ui8;
+  uint32_t ui32, index, sysUpTime, unix_secs, unix_nsecs, First, Last;
+  uint16_t ui16;
+  uint8_t ui8;
 
   ftio_get_ver(ftio, &ftv);
 
@@ -334,145 +333,145 @@ int format0(struct ftio *ftio, struct options *opt)
     fwrite(&index, sizeof (index), 1, stdout);
 
     if (opt->cflowd_mask & CF_ROUTERMASK) {
-       ui32 = *((u_int32*)(rec+fo.exaddr));
+       ui32 = *((uint32_t*)(rec+fo.exaddr));
        ui32 = htonl(ui32);
        fwrite(&ui32, sizeof (ui32), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_SRCIPADDRMASK) {
-       ui32 = *((u_int32*)(rec+fo.srcaddr));
+       ui32 = *((uint32_t*)(rec+fo.srcaddr));
        ui32 = htonl(ui32);
        fwrite(&ui32, sizeof (ui32), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_DSTIPADDRMASK) {
-       ui32 = *((u_int32*)(rec+fo.dstaddr));
+       ui32 = *((uint32_t*)(rec+fo.dstaddr));
        ui32 = htonl(ui32);
        fwrite(&ui32, sizeof (ui32), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_INPUTIFINDEXMASK) {
-       ui16 = *((u_int16*)(rec+fo.input));
+       ui16 = *((uint16_t*)(rec+fo.input));
        ui16 = htons(ui16);
        fwrite(&ui16, sizeof (ui16), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_OUTPUTIFINDEXMASK) {
-       ui16 = *((u_int16*)(rec+fo.output));
+       ui16 = *((uint16_t*)(rec+fo.output));
        ui16 = htons(ui16);
        fwrite(&ui16, sizeof (ui16), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_SRCPORTMASK) {
-       ui16 = *((u_int16*)(rec+fo.srcport));
+       ui16 = *((uint16_t*)(rec+fo.srcport));
        ui16 = htons(ui16);
        fwrite(&ui16, sizeof (ui16), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_DSTPORTMASK) {
-       ui16 = *((u_int16*)(rec+fo.dstport));
+       ui16 = *((uint16_t*)(rec+fo.dstport));
        ui16 = htons(ui16);
        fwrite(&ui16, sizeof (ui16), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_PKTSMASK) {
-       ui32 = *((u_int32*)(rec+fo.dPkts));
+       ui32 = *((uint32_t*)(rec+fo.dPkts));
        ui32 = htonl(ui32);
        fwrite(&ui32, sizeof (ui32), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_BYTESMASK) {
-       ui32 = *((u_int32*)(rec+fo.dOctets));
+       ui32 = *((uint32_t*)(rec+fo.dOctets));
        ui32 = htonl(ui32);
        fwrite(&ui32, sizeof (ui32), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_IPNEXTHOPMASK) {
-       ui32 = *((u_int32*)(rec+fo.nexthop));
+       ui32 = *((uint32_t*)(rec+fo.nexthop));
        ui32 = htonl(ui32);
        fwrite(&ui32, sizeof (ui32), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_STARTTIMEMASK) {
-       sysUpTime = *((u_int32*)(rec+fo.sysUpTime));
-       unix_secs = *((u_int32*)(rec+fo.unix_secs));
-       unix_nsecs = *((u_int32*)(rec+fo.unix_nsecs));
-       First = *((u_int32*)(rec+fo.First));
+       sysUpTime = *((uint32_t*)(rec+fo.sysUpTime));
+       unix_secs = *((uint32_t*)(rec+fo.unix_secs));
+       unix_nsecs = *((uint32_t*)(rec+fo.unix_nsecs));
+       First = *((uint32_t*)(rec+fo.First));
        ftt = ftltime(sysUpTime, unix_secs, unix_nsecs, First);
        ui32 = htonl(ftt.secs);
        fwrite(&ui32, sizeof (ui32), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_ENDTIMEMASK) {
-       sysUpTime = *((u_int32*)(rec+fo.sysUpTime));
-       unix_secs = *((u_int32*)(rec+fo.unix_secs));
-       unix_nsecs = *((u_int32*)(rec+fo.unix_nsecs));
-       Last = *((u_int32*)(rec+fo.Last));
+       sysUpTime = *((uint32_t*)(rec+fo.sysUpTime));
+       unix_secs = *((uint32_t*)(rec+fo.unix_secs));
+       unix_nsecs = *((uint32_t*)(rec+fo.unix_nsecs));
+       Last = *((uint32_t*)(rec+fo.Last));
        ftt = ftltime(sysUpTime, unix_secs, unix_nsecs, Last);
        ui32 = htonl(ftt.secs);
        fwrite(&ui32, sizeof (ui32), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_PROTOCOLMASK) {
-       ui8 = *((u_int8*)(rec+fo.prot));
+       ui8 = *((uint8_t*)(rec+fo.prot));
        fwrite(&ui8, sizeof (ui8), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_TOSMASK) {
-       ui8 = *((u_int8*)(rec+fo.tos));
+       ui8 = *((uint8_t*)(rec+fo.tos));
        fwrite(&ui8, sizeof (ui8), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_SRCASMASK) {
-       ui16 = *((u_int16*)(rec+fo.src_as));
+       ui16 = *((uint16_t*)(rec+fo.src_as));
        ui16 = htons(ui16);
        fwrite(&ui16, sizeof (ui16), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_DSTASMASK) {
-       ui16 = *((u_int16*)(rec+fo.dst_as));
+       ui16 = *((uint16_t*)(rec+fo.dst_as));
        ui16 = htons(ui16);
        fwrite(&ui16, sizeof (ui16), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_SRCMASKLENMASK) {
-       ui8 = *((u_int8*)(rec+fo.src_mask));
+       ui8 = *((uint8_t*)(rec+fo.src_mask));
        fwrite(&ui8, sizeof (ui8), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_DSTMASKLENMASK) {
-       ui8 = *((u_int8*)(rec+fo.dst_mask));
+       ui8 = *((uint8_t*)(rec+fo.dst_mask));
        fwrite(&ui8, sizeof (ui8), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_TCPFLAGSMASK) {
-       ui8 = *((u_int8*)(rec+fo.tcp_flags));
+       ui8 = *((uint8_t*)(rec+fo.tcp_flags));
        fwrite(&ui8, sizeof (ui8), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_INPUTENCAPMASK) {
-       ui8 = *((u_int8*)(rec+fo.in_encaps));
+       ui8 = *((uint8_t*)(rec+fo.in_encaps));
        fwrite(&ui8, sizeof (ui8), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_OUTPUTENCAPMASK) {
-       ui8 = *((u_int8*)(rec+fo.out_encaps));
+       ui8 = *((uint8_t*)(rec+fo.out_encaps));
        fwrite(&ui8, sizeof (ui8), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_PEERNEXTHOPMASK) {
-       ui32 = *((u_int32*)(rec+fo.peer_nexthop));
+       ui32 = *((uint32_t*)(rec+fo.peer_nexthop));
        ui32 = htonl(ui32);
        fwrite(&ui32, sizeof (ui32), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_ENGINETYPEMASK) {
-       ui8 = *((u_int8*)(rec+fo.engine_type));
+       ui8 = *((uint8_t*)(rec+fo.engine_type));
        fwrite(&ui8, sizeof (ui8), 1, stdout);
     }
 
     if (opt->cflowd_mask & CF_ENGINEIDMASK) {
-       ui8 = *((u_int8*)(rec+fo.engine_id));
+       ui8 = *((uint8_t*)(rec+fo.engine_id));
        fwrite(&ui8, sizeof (ui8), 1, stdout);
     }
 
@@ -502,14 +501,16 @@ int format1(struct ftio *ftio, struct options *opt)
   struct pcap_data2 pd2;
   struct pcap_data3 pd3;
   struct pcap_data4 pd4;
-  int bsize, bsize2, good;
+  int bsize, bsize2;
   long thiszone;
   char buf[1024];
   char *rec;
 
   if (ftio_check_xfield(ftio, FT_XFIELD_TOS | FT_XFIELD_PROT | 
     FT_XFIELD_SRCADDR | FT_XFIELD_DSTADDR | FT_XFIELD_SRCPORT |
-    FT_XFIELD_DSTPORT)) {
+    FT_XFIELD_DSTPORT |
+    FT_XFIELD_UNIX_SECS | FT_XFIELD_UNIX_NSECS |
+    FT_XFIELD_DPKTS | FT_XFIELD_DOCTETS)) {
     fterr_warnx("Flow record missing required field for format.");
     return -1;
   }
@@ -525,23 +526,17 @@ int format1(struct ftio *ftio, struct options *opt)
 
   bzero(&pfh, sizeof pfh);
   bzero(&pph, sizeof pph);
-  bzero(&pd1, sizeof pd1);
-  bzero(&pd2, sizeof pd2);
-  bzero(&pd3, sizeof pd3);
-  bzero(&pd4, sizeof pd4);
+  bzero(&pd1, sizeof pd1); /* ethernet */
+  bzero(&pd2, sizeof pd2); /* IP */
+  bzero(&pd3, sizeof pd3); /* TCP */
+  bzero(&pd4, sizeof pd4); /* UDP */
   bsize = 0;
 
-  thiszone = tz.tz_minuteswest * -60;
-
-  if (localtime((time_t *)&now.tv_sec)->tm_isdst)
-    thiszone += 3600;
-
   pfh.magic = TCPDUMP_MAGIC;  
   pfh.version_major = TCPDUMP_VERSION_MAJOR;
   pfh.version_minor = TCPDUMP_VERSION_MINOR;
-  pfh.thiszone = thiszone;
   pfh.sigfigs = 6;
-  pfh.snaplen = 38; /* XXX TODO */
+  pfh.snaplen = 65535;
   pfh.linktype = 1;
 
   if (fwrite(&pfh, sizeof pfh, 1, stdout) != 1) {
@@ -549,13 +544,10 @@ int format1(struct ftio *ftio, struct options *opt)
     return -1;
   }
 
-  pph.len = 58;
-  pph.caplen = 58;
-
   pd1.eth_prot = 0x0008;
   pd2.version = 0x45;
 
-  bcopy(&pph, buf, sizeof pph);
+  /* note: bcopy of pph to buf is deferred (so lengths can be adjusted below) */
   bsize += sizeof pph;
 
   bcopy(&pd1, buf+bsize, sizeof pd1);
@@ -563,45 +555,56 @@ int format1(struct ftio *ftio, struct options *opt)
 
   while ((rec = ftio_read(ftio))) {
 
-    cur.srcport = ((u_int16*)(rec+fo.srcport));
-    cur.dstport = ((u_int16*)(rec+fo.dstport));
-    cur.prot = ((u_int8*)(rec+fo.prot));
-    cur.tos = ((u_int8*)(rec+fo.tos));
-    cur.srcaddr = ((u_int32*)(rec+fo.srcaddr));
-    cur.dstaddr = ((u_int32*)(rec+fo.dstaddr));
-
+    cur.unix_secs = (uint32_t *)(rec+fo.unix_secs);
+    cur.unix_nsecs = (uint32_t *)(rec+fo.unix_nsecs);
+    cur.srcport = ((uint16_t*)(rec+fo.srcport));
+    cur.dstport = ((uint16_t*)(rec+fo.dstport));
+    cur.prot = ((uint8_t*)(rec+fo.prot));
+    cur.tos = ((uint8_t*)(rec+fo.tos));
+    cur.srcaddr = ((uint32_t*)(rec+fo.srcaddr));
+    cur.dstaddr = ((uint32_t*)(rec+fo.dstaddr));
 
+    pd2.version = 4 << 4 | ((sizeof pd2) / 4);
     pd2.tos = *cur.tos;
     pd2.prot = *cur.prot;
     pd2.srcaddr = *cur.srcaddr;
     pd2.dstaddr = *cur.dstaddr;
+    pd2.len = sizeof pd2; /* this might be adjusted below for TCP, UDP, etc. */
+
+    pph.caplen = sizeof pd1 + sizeof pd2; /* ether and IP header */
 
 #if BYTE_ORDER == LITTLE_ENDIAN
     SWAPINT32(pd2.srcaddr);
     SWAPINT32(pd2.dstaddr);
 #endif /* LITTLE_ENDIAN */
 
-    good = 1;
+#if 1 /* { */
 
     switch (pd2.prot) {
 
-    case 6:
+    case 6: /* TCP */
 
       pd3.srcport = *cur.srcport;
       pd3.dstport = *cur.dstport;
-
 #if BYTE_ORDER == LITTLE_ENDIAN
       SWAPINT16(pd3.srcport);
       SWAPINT16(pd3.dstport);
 #endif /* LITTLE_ENDIAN */
 
-      bcopy(&pd2, buf+bsize, sizeof pd2);
+      /* set data offset to 6 32-bit words: */
+      pd3.data_reserved_flags_window = 0x60000000;
+#if BYTE_ORDER == LITTLE_ENDIAN
+      SWAPINT32(pd3.data_reserved_flags_window);
+#endif /* LITTLE_ENDIAN */
+
+      pph.caplen += sizeof pd3; /* + TCP header */
+      pd2.len += sizeof pd3;
       bcopy(&pd3, buf+bsize+sizeof pd2, sizeof pd3);
       bsize2 = bsize + sizeof pd2 + sizeof pd3;
 
       break;
 
-    case 17:
+    case 17: /* UDP */
 
       pd4.srcport = *cur.srcport;
       pd4.dstport = *cur.dstport;
@@ -611,19 +614,47 @@ int format1(struct ftio *ftio, struct options *opt)
       SWAPINT16(pd4.dstport);
 #endif /* LITTLE_ENDIAN */
 
-      bcopy(&pd2, buf+bsize, sizeof pd2);
+      pph.caplen += sizeof pd4; /* + UDP header */
+      pd2.len += sizeof pd4;
+      pd4.len = sizeof pd4; /* FIXME */
+#if BYTE_ORDER == LITTLE_ENDIAN
+      SWAPINT16(pd4.len);
+#endif /* LITTLE_ENDIAN */
       bcopy(&pd4, buf+bsize+sizeof pd2, sizeof pd4);
       bsize2 = bsize + sizeof pd2 + sizeof pd4;
 
       break;
 
-    default:
-      good = 0;
+    case 1: /* FIXME - handle ICMP specially */
+    default: /* handle others IP protocols */
+      bsize2 = bsize + sizeof pd2;
       break;
 
     } /* switch */
 
-    if (good) {
+#else /* }{ */
+    bsize2 = bsize + sizeof pd2;
+#endif /* } */
+
+    pph.ts.tv_sec = *(uint32_t *)(rec+fo.unix_secs);
+    pph.ts.tv_usec = *(uint32_t *)(rec+fo.unix_nsecs) / 1000;
+    pph.len = pph.caplen; /* FIXME */
+
+    bcopy(&pph, buf, sizeof pph);
+#if BYTE_ORDER == LITTLE_ENDIAN
+    SWAPINT16(pd2.len);
+#endif /* LITTLE_ENDIAN */
+    bcopy(&pd2, buf+bsize, sizeof pd2);
+
+    {
+      /* FIXME - add a loop here to write one record per packet (rather than
+       *         one per flow).  change the packet size to be
+       *         floor(average_pkt_size), then add one byte to the first or
+       *         last flow, if necessary, to make the byte count correct.
+       */
+       /* uint16_t dPkts; */
+       /* uint16_t dOctets; */
+
       if (fwrite(&buf, bsize2, 1, stdout) != 1) {
         fterr_warnx("pcap pkt write failed");
         return -1;
@@ -695,12 +726,12 @@ int format3(struct ftio *ftio, struct options *opt)
 
   MYSQL mysql;
 
-  db_host = DB_DEFAULT_DBHOST;
-  db_name = DB_DEFAULT_DBNAME;
-  db_port = DB_DEFAULT_DBPORT;
-  db_user = DB_DEFAULT_DBUSER;
-  db_table = DB_DEFAULT_DBTABLE;
-  db_pwd = DB_DEFAULT_DBPWD;
+  db_host = MYSQL_DEFAULT_DBHOST;
+  db_name = MYSQL_DEFAULT_DBNAME;
+  db_port = MYSQL_DEFAULT_DBPORT;
+  db_user = MYSQL_DEFAULT_DBUSER;
+  db_table = MYSQL_DEFAULT_DBTABLE;
+  db_pwd = MYSQL_DEFAULT_DBPWD;
 
   /* parse URI string */
 
@@ -860,7 +891,7 @@ retry:
  */
 int format5(struct ftio *ftio, struct options *opt)
 {
-#ifdef HAVE_PGSQL
+#ifdef HAVE_POSTGRESQL
   struct fts3rec_offsets fo;
   struct ftver ftv;
   char fields[1024], values[1024], query[3*1024];
@@ -872,12 +903,12 @@ int format5(struct ftio *ftio, struct options *opt)
   PGconn     *conn;
   PGresult   *res;
 
-  db_host = DB_DEFAULT_DBHOST;
-  db_name = DB_DEFAULT_DBNAME;
-  db_port = DB_DEFAULT_DBPORT;
-  db_user = DB_DEFAULT_DBUSER;
-  db_table = DB_DEFAULT_DBTABLE;
-  db_pwd = DB_DEFAULT_DBPWD;
+  db_host = POSTGRESQL_DEFAULT_DBHOST;
+  db_name = POSTGRESQL_DEFAULT_DBNAME;
+  db_port = POSTGRESQL_DEFAULT_DBPORT;
+  db_user = POSTGRESQL_DEFAULT_DBUSER;
+  db_table = POSTGRESQL_DEFAULT_DBTABLE;
+  db_pwd = POSTGRESQL_DEFAULT_DBPWD;
 
   /* parse URI string */
 
@@ -892,7 +923,7 @@ int format5(struct ftio *ftio, struct options *opt)
     db_name = strsep(&tmp, ":");
     db_table = strsep(&tmp, ":");
 
-    if (!db_user || !db_pwd || !db_host || !db_tmp || !db_name || !db_table) {
+    if (!db_user || !db_pwd || !db_host || !db_port || !db_name || !db_table) {
       fterr_warnx("Missing field in dbaseURI, expecting user:pwd:host:port:name:table.");
       return -1;
     }
@@ -938,6 +969,8 @@ int format5(struct ftio *ftio, struct options *opt)
       if (!res || PQresultStatus(res) != PGRES_COMMAND_OK) {
         PQclear(res);
         fterr_errx(1,"PQexec(): %s\n", PQerrorMessage(conn));
+      } else if (res) {
+	  PQclear(res);
       }
 
     }
@@ -959,9 +992,9 @@ int format5(struct ftio *ftio, struct options *opt)
  
 } /* format5 */ 
 
-int fmt_xfields_type(char *buf, u_int64 xfield)
+int fmt_xfields_type(char *buf, uint64_t xfield)
 {
-  int comma;
+  int comma = 0;
 
   buf[0] = 0;
 
@@ -1169,7 +1202,7 @@ int fmt_xfields_type(char *buf, u_int64 xfield)
 
 
 int fmt_xfields_val(char *fmt_buf, char *rec, struct fts3rec_offsets *fo,
-  u_int64 xfields, int quote)
+  uint64_t xfields, int quote)
 {
   int comma, len;
 
@@ -1179,243 +1212,243 @@ int fmt_xfields_val(char *fmt_buf, char *rec, struct fts3rec_offsets *fo,
 
   if (xfields & FT_XFIELD_UNIX_SECS) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint32(fmt_buf+len, *((u_int32*)(rec+fo->unix_secs)),
+    len += fmt_uint32(fmt_buf+len, *((uint32_t*)(rec+fo->unix_secs)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_UNIX_NSECS) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint32(fmt_buf+len, *((u_int32*)(rec+fo->unix_nsecs)),
+    len += fmt_uint32(fmt_buf+len, *((uint32_t*)(rec+fo->unix_nsecs)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_SYSUPTIME) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint32(fmt_buf+len, *((u_int32*)(rec+fo->sysUpTime)),
+    len += fmt_uint32(fmt_buf+len, *((uint32_t*)(rec+fo->sysUpTime)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_EXADDR) {
     if (comma) fmt_buf[len++] = ',';
-    if (quote) fmt_buf[len++] = '"';
-    len += fmt_ipv4(fmt_buf+len, *((u_int32*)(rec+fo->exaddr)),
+    if (quote) fmt_buf[len++] = '\'';
+    len += fmt_ipv4(fmt_buf+len, *((uint32_t*)(rec+fo->exaddr)),
       FMT_JUST_LEFT);
-    if (quote) fmt_buf[len++] = '"';
+    if (quote) fmt_buf[len++] = '\'';
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_DFLOWS) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint32(fmt_buf+len, *((u_int32*)(rec+fo->dFlows)),
+    len += fmt_uint32(fmt_buf+len, *((uint32_t*)(rec+fo->dFlows)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_DPKTS) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint32(fmt_buf+len, *((u_int32*)(rec+fo->dPkts)),
+    len += fmt_uint32(fmt_buf+len, *((uint32_t*)(rec+fo->dPkts)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_DOCTETS) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint32(fmt_buf+len, *((u_int32*)(rec+fo->dOctets)),
+    len += fmt_uint32(fmt_buf+len, *((uint32_t*)(rec+fo->dOctets)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_FIRST) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint32(fmt_buf+len, *((u_int32*)(rec+fo->First)),
+    len += fmt_uint32(fmt_buf+len, *((uint32_t*)(rec+fo->First)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_LAST) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint32(fmt_buf+len, *((u_int32*)(rec+fo->Last)),
+    len += fmt_uint32(fmt_buf+len, *((uint32_t*)(rec+fo->Last)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_ENGINE_TYPE) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint8(fmt_buf+len, *((u_int8*)(rec+fo->engine_type)),
+    len += fmt_uint8(fmt_buf+len, *((uint8_t*)(rec+fo->engine_type)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_ENGINE_ID) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint8(fmt_buf+len, *((u_int8*)(rec+fo->engine_id)),
+    len += fmt_uint8(fmt_buf+len, *((uint8_t*)(rec+fo->engine_id)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_SRCADDR) {
     if (comma) fmt_buf[len++] = ',';
-    if (quote) fmt_buf[len++] = '"';
-    len += fmt_ipv4(fmt_buf+len, *((u_int32*)(rec+fo->srcaddr)),
+    if (quote) fmt_buf[len++] = '\'';
+    len += fmt_ipv4(fmt_buf+len, *((uint32_t*)(rec+fo->srcaddr)),
       FMT_JUST_LEFT);
-    if (quote) fmt_buf[len++] = '"';
+    if (quote) fmt_buf[len++] = '\'';
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_DSTADDR) {
     if (comma) fmt_buf[len++] = ',';
-    if (quote) fmt_buf[len++] = '"';
-    len += fmt_ipv4(fmt_buf+len, *((u_int32*)(rec+fo->dstaddr)),
+    if (quote) fmt_buf[len++] = '\'';
+    len += fmt_ipv4(fmt_buf+len, *((uint32_t*)(rec+fo->dstaddr)),
       FMT_JUST_LEFT);
-    if (quote) fmt_buf[len++] = '"';
+    if (quote) fmt_buf[len++] = '\'';
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_NEXTHOP) {
     if (comma) fmt_buf[len++] = ',';
-    if (quote) fmt_buf[len++] = '"';
-    len += fmt_ipv4(fmt_buf+len, *((u_int32*)(rec+fo->nexthop)),
+    if (quote) fmt_buf[len++] = '\'';
+    len += fmt_ipv4(fmt_buf+len, *((uint32_t*)(rec+fo->nexthop)),
       FMT_JUST_LEFT);
-    if (quote) fmt_buf[len++] = '"';
+    if (quote) fmt_buf[len++] = '\'';
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_INPUT) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint16(fmt_buf+len, *((u_int16*)(rec+fo->input)),
+    len += fmt_uint16(fmt_buf+len, *((uint16_t*)(rec+fo->input)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_OUTPUT) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint16(fmt_buf+len, *((u_int16*)(rec+fo->output)),
+    len += fmt_uint16(fmt_buf+len, *((uint16_t*)(rec+fo->output)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_SRCPORT) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint16(fmt_buf+len, *((u_int16*)(rec+fo->srcport)),
+    len += fmt_uint16(fmt_buf+len, *((uint16_t*)(rec+fo->srcport)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_DSTPORT) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint16(fmt_buf+len, *((u_int16*)(rec+fo->dstport)),
+    len += fmt_uint16(fmt_buf+len, *((uint16_t*)(rec+fo->dstport)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_PROT) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint8(fmt_buf+len, *((u_int8*)(rec+fo->prot)),
+    len += fmt_uint8(fmt_buf+len, *((uint8_t*)(rec+fo->prot)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_TOS) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint8(fmt_buf+len, *((u_int8*)(rec+fo->tos)),
+    len += fmt_uint8(fmt_buf+len, *((uint8_t*)(rec+fo->tos)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_TCP_FLAGS) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint8(fmt_buf+len, *((u_int8*)(rec+fo->tcp_flags)),
+    len += fmt_uint8(fmt_buf+len, *((uint8_t*)(rec+fo->tcp_flags)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_SRC_MASK) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint8(fmt_buf+len, *((u_int8*)(rec+fo->src_mask)),
+    len += fmt_uint8(fmt_buf+len, *((uint8_t*)(rec+fo->src_mask)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_DST_MASK) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint8(fmt_buf+len, *((u_int8*)(rec+fo->dst_mask)),
+    len += fmt_uint8(fmt_buf+len, *((uint8_t*)(rec+fo->dst_mask)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_SRC_AS) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint16(fmt_buf+len, *((u_int16*)(rec+fo->src_as)),
+    len += fmt_uint16(fmt_buf+len, *((uint16_t*)(rec+fo->src_as)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_DST_AS) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint16(fmt_buf+len, *((u_int16*)(rec+fo->dst_as)),
+    len += fmt_uint16(fmt_buf+len, *((uint16_t*)(rec+fo->dst_as)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_IN_ENCAPS) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint8(fmt_buf+len, *((u_int8*)(rec+fo->in_encaps)),
+    len += fmt_uint8(fmt_buf+len, *((uint8_t*)(rec+fo->in_encaps)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_OUT_ENCAPS) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint8(fmt_buf+len, *((u_int8*)(rec+fo->out_encaps)),
+    len += fmt_uint8(fmt_buf+len, *((uint8_t*)(rec+fo->out_encaps)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_PEER_NEXTHOP) {
     if (comma) fmt_buf[len++] = ',';
-    if (quote) fmt_buf[len++] = '"';
-    len += fmt_ipv4(fmt_buf+len, *((u_int32*)(rec+fo->peer_nexthop)),
+    if (quote) fmt_buf[len++] = '\"';
+    len += fmt_ipv4(fmt_buf+len, *((uint32_t*)(rec+fo->peer_nexthop)),
       FMT_JUST_LEFT);
-    if (quote) fmt_buf[len++] = '"';
+    if (quote) fmt_buf[len++] = '\'';
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_ROUTER_SC) {
     if (comma) fmt_buf[len++] = ',';
-    if (quote) fmt_buf[len++] = '"';
-    len += fmt_ipv4(fmt_buf+len, *((u_int32*)(rec+fo->router_sc)),
+    if (quote) fmt_buf[len++] = '\'';
+    len += fmt_ipv4(fmt_buf+len, *((uint32_t*)(rec+fo->router_sc)),
       FMT_JUST_LEFT);
-    if (quote) fmt_buf[len++] = '"';
+    if (quote) fmt_buf[len++] = '\'';
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_MARKED_TOS) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint8(fmt_buf+len, *((u_int8*)(rec+fo->marked_tos)),
+    len += fmt_uint8(fmt_buf+len, *((uint8_t*)(rec+fo->marked_tos)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_EXTRA_PKTS) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint32(fmt_buf+len, *((u_int32*)(rec+fo->extra_pkts)),
+    len += fmt_uint32(fmt_buf+len, *((uint32_t*)(rec+fo->extra_pkts)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_SRC_TAG) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint32(fmt_buf+len, *((u_int32*)(rec+fo->src_tag)),
+    len += fmt_uint32(fmt_buf+len, *((uint32_t*)(rec+fo->src_tag)),
       FMT_JUST_LEFT);
     comma = 1;
   }
 
   if (xfields & FT_XFIELD_DST_TAG) {
     if (comma) fmt_buf[len++] = ',';
-    len += fmt_uint32(fmt_buf+len, *((u_int32*)(rec+fo->dst_tag)),
+    len += fmt_uint32(fmt_buf+len, *((uint32_t*)(rec+fo->dst_tag)),
       FMT_JUST_LEFT);
     comma = 1;
   }
@@ -1430,7 +1463,6 @@ int fmt_xfields_val(char *fmt_buf, char *rec, struct fts3rec_offsets *fo,
 void usage(void) {
 
   fprintf(stderr, "Usage: flow-export [-h] [-d debug_level] [-f format] [-m mask_fields] -u [database URI]\n");
-  fprintf(stderr, "\n%s version %s: built by %s\n", PACKAGE, VERSION, FT_PROG_BUILD);
 
 
 } /* usage */
@@ -1443,7 +1475,7 @@ void usage(void) {
  * returns 0:  ok
  *         <0  fail
  */
-int ftxfield_tocflow(u_int64 xfields, u_int32 *cfmask)
+int ftxfield_tocflow(uint64_t xfields, uint32_t *cfmask)
 {
   int droptime;
 
