@@ -56,7 +56,6 @@
   #include <string.h>
 #endif
 
-#include "ftbuild.h"
 
 #define FANOUT_PIDFILE    "/var/run/flow-fanout.pid"
 
@@ -81,10 +80,10 @@ void fterr_exit_handler(int code);
 int sig_quit_flag, sig_hup_flag, sig_term_flag, reload_flag;
 void sig_quit(int), sig_hup(int), sig_term(int);
 pid_t pid;
-u_int16 listen_port;
+uint16_t listen_port;
 
 void pdu_xmit(int npeers, int tx_delay, int src_ip_spoof, int hdr_len,
-  u_int32 *send_nobufs, struct ip *ip_hdr, struct udphdr *udp_hdr,
+  uint32_t *send_nobufs, struct ip *ip_hdr, struct udphdr *udp_hdr,
   struct ftencode *fte, struct peer *peers, struct ftnet *ftnet);
 
 int main(int argc, char **argv)
@@ -116,17 +115,22 @@ int main(int argc, char **argv)
   struct ftvar ftvar;
   struct peer *peers;
   struct ftipmask ftipmask;
-  u_int32 flows_corrupt, flows_lost, flows_reset, hash, privacy_mask;
-  u_int32 send_nobufs;
+  uint32_t flows_corrupt, flows_lost, flows_reset, hash, privacy_mask;
+  uint32_t send_nobufs;
   unsigned int v1, v2;
   char fmt_src_ip[32], fmt_dst_ip[32], fmt_dst_port[32];
   char xl_rec[FT_IO_MAXREC], *out_rec;
-  char *filter_fname, *filter_active;
+  const char *filter_fname, *filter_active;
   int i, n, detach, one, ret, offset, hdr_len;
   int npeers, tx_delay;
   int stat_interval, stat_next, src_ip_spoof;
+#ifdef IP_RECVDSTADDR
+#ifdef CMSG_DATA
+  struct cmsghdr *cmsg;
+#endif
+#endif
 
-  time_startup = time((time_t)0L);
+  time_startup = time(NULL);
 
   /* init fterr */
   fterr_setid(argv[0]);
@@ -566,7 +570,7 @@ mcast_done:
       }
     }
 
-    now = time((time_t)0L);
+    now = time(NULL);
 
     /* reset */
     bzero (&tv, sizeof tv);
@@ -626,12 +630,24 @@ restart_recvmsg:
 
 #ifdef IP_RECVDSTADDR
       /* got destination IP back? */
+#ifdef CMSG_DATA
+      for (cmsg = CMSG_FIRSTHDR(&ftnet.msg); cmsg != NULL;
+          cmsg = CMSG_NXTHDR(&ftnet.msg, cmsg)) {
+              if (cmsg->cmsg_level == IPPROTO_IP &&
+                  cmsg->cmsg_type == IP_RECVDSTADDR) {
+                      memcpy(&ftnet.loc_addr.sin_addr.s_addr,
+                          CMSG_DATA(cmsg), sizeof(struct in_addr));
+                      break;
+              }
+      }
+#else
       if ((ftnet.msgip.hdr.cmsg_level == IPPROTO_IP) &&
           (ftnet.msgip.hdr.cmsg_type == IP_RECVDSTADDR)) {
           ftnet.loc_addr.sin_addr.s_addr = ftnet.msgip.ip.s_addr;
       } else {
         ftnet.loc_addr.sin_addr.s_addr = 0;
       }
+#endif /* CMSG_DATA */
 #else
 #ifdef IP_PKTINFO
       if ((ftnet.msgip.hdr.cmsg_level == IPPROTO_IP) &&
@@ -855,6 +871,7 @@ retry:
     } /* if FD_ISSET */
 
 skip1:
+    ;
 
     if (sig_quit_flag) {
       fterr_info("SIGQUIT");
@@ -908,7 +925,7 @@ void fterr_exit_handler(int code)
 } /* fterr_exit_handler */
  
 void pdu_xmit(int npeers, int tx_delay, int src_ip_spoof, int hdr_len,
-  u_int32 *send_nobufs, struct ip *ip_hdr, struct udphdr *udp_hdr,
+  uint32_t *send_nobufs, struct ip *ip_hdr, struct udphdr *udp_hdr,
   struct ftencode *fte, struct peer *peers, struct ftnet *ftnet)
 {
   int j, sum;
@@ -986,6 +1003,5 @@ void usage(void)
   fprintf(stderr, "usage: flow-fanout [-hDs] [-A AS0_substitution] [-d debug_level]\n");
   fprintf(stderr, "       [-m privacy_mask] [-p pidfile] [-S stat_interval] [-V pdu_version]\n");
   fprintf(stderr, "       [-x] xmit_delay] localip/remoteip/port localip/remoteip/port ...\n");
-  fprintf(stderr, "\n%s version %s: built by %s\n", PACKAGE, VERSION, FT_PROG_BUILD);
 
 } /* usage */
