@@ -46,9 +46,7 @@
   #include <string.h>
 #endif
 
-#include "ftbuild.h"
 #include "acl2.h"
-#include "aclyacc.h"
 
 /*
  * TODO
@@ -75,7 +73,7 @@ int main(int argc, char **argv)
   struct ftset ftset;
   struct ftver ftv;
   struct ftprof ftp;
-  u_int32 time_start, time_end, exaddr;
+  uint32_t time_start, time_end, exaddr;
   int i, ret;
   char *acl_fname, *acl_std_src_name, *acl_std_dst_name;
   char *acl_std_nexthop_name;
@@ -94,7 +92,7 @@ int main(int argc, char **argv)
   char tcp_flags_tbl[65536];
   char prot_tbl[256];
   u_char tos_mask, tos, tcp_flags_mask, tcp_flags;
-  u_int64 total_flows, xflag;
+  uint64_t total_flows, xflag;
   char *rec;
   int first_match = 0;
 
@@ -411,19 +409,19 @@ int main(int argc, char **argv)
   /* grab 1 flow */
   while ((rec = ftio_read(&ftio_in))) {
 
-    cur.srcaddr = ((u_int32*)(rec+fo.srcaddr));
-    cur.dstaddr = ((u_int32*)(rec+fo.dstaddr));
-    cur.exaddr = ((u_int32*)(rec+fo.exaddr));
-    cur.nexthop = ((u_int32*)(rec+fo.nexthop));
-    cur.input = ((u_int16*)(rec+fo.input));
-    cur.output = ((u_int16*)(rec+fo.output));
-    cur.srcport = ((u_int16*)(rec+fo.srcport));
-    cur.dstport = ((u_int16*)(rec+fo.dstport));
-    cur.src_as = ((u_int16*)(rec+fo.src_as));
-    cur.dst_as = ((u_int16*)(rec+fo.dst_as));
-    cur.prot = ((u_int8*)(rec+fo.prot));
-    cur.tcp_flags = ((u_int8*)(rec+fo.tcp_flags));
-    cur.tos = ((u_int8*)(rec+fo.tos));
+    cur.srcaddr = ((uint32_t*)(rec+fo.srcaddr));
+    cur.dstaddr = ((uint32_t*)(rec+fo.dstaddr));
+    cur.exaddr = ((uint32_t*)(rec+fo.exaddr));
+    cur.nexthop = ((uint32_t*)(rec+fo.nexthop));
+    cur.input = ((uint16_t*)(rec+fo.input));
+    cur.output = ((uint16_t*)(rec+fo.output));
+    cur.srcport = ((uint16_t*)(rec+fo.srcport));
+    cur.dstport = ((uint16_t*)(rec+fo.dstport));
+    cur.src_as = ((uint16_t*)(rec+fo.src_as));
+    cur.dst_as = ((uint16_t*)(rec+fo.dst_as));
+    cur.prot = ((uint8_t*)(rec+fo.prot));
+    cur.tcp_flags = ((uint8_t*)(rec+fo.tcp_flags));
+    cur.tos = ((uint8_t*)(rec+fo.tos));
 
     ++ total_flows;
 
@@ -629,14 +627,11 @@ void yyerror(const char *msg)
 }
 
 void usage(void) {
-
   fprintf(stderr, "Usage: flow-filter [-hko] [-a src_as_filter] [-A dst_as_filter] [-b big|little]\n");
   fprintf(stderr, "       [-C comment] [-D dstaddr_filter_name] [-d debug_level] [-e exaddr]\n");
   fprintf(stderr, "       [-f acl_fname] [-i input_filter] [-I output_filter]  [-p srcport_filter]\n");
   fprintf(stderr, "       [-P dstport_filter] [-r ipprot_filter] [-S srcaddr_filter_name]\n");
   fprintf(stderr, "       [-t tos_filter] [-T tcp_flags_filter] [-x nexthop_filter_name]\n");
   fprintf(stderr, "       [-z z_level]\n");
-  fprintf(stderr, "\n%s version %s: built by %s\n", PACKAGE, VERSION, FT_PROG_BUILD);
-
 } /* usage */
 
