@@ -53,13 +53,12 @@
   char    *strsep (char **, const char *);
 #endif
 
-#include "ftbuild.h"
 #include "cflowd.h"
 
 struct options {
   struct ftver ftv;
   struct ftset ftset;
-  u_int64 ft_mask;
+  uint64_t ft_mask;
   int set_format;
   u_long records;
 };
@@ -79,7 +78,7 @@ void usage(void);
 struct jump format[] = {{format0}, {format1}, {format2},
 			{ format_NFCollector1 }, {format4} };
 
-static u_int64 vXmask[] = {
+static uint64_t vXmask[] = {
   0,
   FT_XFIELD_V1_MASK,
   0, 0, 0,
@@ -87,7 +86,7 @@ static u_int64 vXmask[] = {
   FT_XFIELD_V6_MASK,
   FT_XFIELD_V7_MASK };
 
-static u_int64 v8mask[] = {
+static uint64_t v8mask[] = {
   0,
   FT_XFIELD_V8_1_MASK,
   FT_XFIELD_V8_2_MASK,
@@ -246,10 +245,10 @@ int format0(struct ftio *ftio, struct options *opt)
   size_t rlen;
   u_char buf[FT_IO_MAXREC];
   char *rec;
-  u_int32 ui32, Start;
-  u_int16 ui16;
-  u_int8 ui8;
-  u_int32 cfdmask, index;
+  uint32_t ui32, Start;
+  uint16_t ui16;
+  uint8_t ui8;
+  uint32_t cfdmask, index;
   int ret;
 
   rec = (char*)&buf;
@@ -364,7 +363,7 @@ int format0(struct ftio *ftio, struct options *opt)
         goto done;
       ui32 = ntohl(ui32);
       if (cfdmask & CF_ROUTERMASK)
-        *((u_int32*)(rec+fo.exaddr)) = ui32;
+        *((uint32_t*)(rec+fo.exaddr)) = ui32;
     }
 
     if (index & CF_SRCIPADDRMASK) {
@@ -372,7 +371,7 @@ int format0(struct ftio *ftio, struct options *opt)
         goto done;
       ui32 = ntohl(ui32);
       if (cfdmask & CF_SRCIPADDRMASK)
-        *((u_int32*)(rec+fo.srcaddr)) = ui32;
+        *((uint32_t*)(rec+fo.srcaddr)) = ui32;
     }
 
     if (index & CF_DSTIPADDRMASK) {
@@ -380,7 +379,7 @@ int format0(struct ftio *ftio, struct options *opt)
         goto done;
       ui32 = ntohl(ui32);
       if (cfdmask & CF_DSTIPADDRMASK)
-        *((u_int32*)(rec+fo.dstaddr)) = ui32;
+        *((uint32_t*)(rec+fo.dstaddr)) = ui32;
     }
 
     if (index & CF_INPUTIFINDEXMASK) {
@@ -388,7 +387,7 @@ int format0(struct ftio *ftio, struct options *opt)
         goto done;
       ui16 = ntohs(ui16);
       if (cfdmask & CF_DSTIPADDRMASK)
-        *((u_int16*)(rec+fo.input)) = ui16;
+        *((uint16_t*)(rec+fo.input)) = ui16;
     }
 
     if (index & CF_OUTPUTIFINDEXMASK) {
@@ -396,7 +395,7 @@ int format0(struct ftio *ftio, struct options *opt)
         goto done;
       ui16 = ntohs(ui16);
       if (cfdmask & CF_OUTPUTIFINDEXMASK)
-        *((u_int16*)(rec+fo.output)) = ui16;
+        *((uint16_t*)(rec+fo.output)) = ui16;
     }
 
     if (index & CF_SRCPORTMASK) {
@@ -404,7 +403,7 @@ int format0(struct ftio *ftio, struct options *opt)
         goto done;
       ui16 = ntohs(ui16);
       if (cfdmask & CF_SRCPORTMASK)
-        *((u_int16*)(rec+fo.srcport)) = ui16;
+        *((uint16_t*)(rec+fo.srcport)) = ui16;
     }
 
     if (index & CF_DSTPORTMASK) {
@@ -412,7 +411,7 @@ int format0(struct ftio *ftio, struct options *opt)
         goto done;
       ui16 = ntohs(ui16);
       if (cfdmask & CF_DSTPORTMASK)
-        *((u_int16*)(rec+fo.dstport)) = ui16;
+        *((uint16_t*)(rec+fo.dstport)) = ui16;
     }
 
     if (index & CF_PKTSMASK) {
@@ -420,7 +419,7 @@ int format0(struct ftio *ftio, struct options *opt)
         goto done;
       ui32 = ntohl(ui32);
       if (cfdmask & CF_PKTSMASK)
-        *((u_int32*)(rec+fo.dPkts)) = ui32;
+        *((uint32_t*)(rec+fo.dPkts)) = ui32;
     }
 
     if (index & CF_BYTESMASK) {
@@ -428,7 +427,7 @@ int format0(struct ftio *ftio, struct options *opt)
         goto done;
       ui32 = ntohl(ui32);
       if (cfdmask & CF_BYTESMASK)
-        *((u_int32*)(rec+fo.dOctets)) = ui32;
+        *((uint32_t*)(rec+fo.dOctets)) = ui32;
     }
 
     if (index & CF_IPNEXTHOPMASK) {
@@ -436,7 +435,7 @@ int format0(struct ftio *ftio, struct options *opt)
         goto done;
       ui32 = ntohl(ui32);
       if (cfdmask & CF_IPNEXTHOPMASK)
-        *((u_int32*)(rec+fo.nexthop)) = ui32;
+        *((uint32_t*)(rec+fo.nexthop)) = ui32;
     }
 
     if (index & CF_STARTTIMEMASK) {
@@ -445,7 +444,7 @@ int format0(struct ftio *ftio, struct options *opt)
       ui32 = ntohl(ui32);
       Start = ui32;
       if (cfdmask & CF_STARTTIMEMASK)
-        *((u_int32*)(rec+fo.unix_secs)) = ui32;
+        *((uint32_t*)(rec+fo.unix_secs)) = ui32;
     }
 
     if (index & CF_ENDTIMEMASK) {
@@ -454,9 +453,9 @@ int format0(struct ftio *ftio, struct options *opt)
       ui32 = ntohl(ui32);
       if (cfdmask & CF_ENDTIMEMASK) {
         if (Start)
-          *((u_int32*)(rec+fo.Last)) = (ui32 - Start) * 1000;
+          *((uint32_t*)(rec+fo.Last)) = (ui32 - Start) * 1000;
         else
-          *((u_int32*)(rec+fo.unix_secs)) = ui32;
+          *((uint32_t*)(rec+fo.unix_secs)) = ui32;
         
       }
     }
@@ -465,14 +464,14 @@ int format0(struct ftio *ftio, struct options *opt)
       if ((rlen = fread(&ui8, sizeof (ui8), 1, stdin) != 1))
         goto done;
       if (cfdmask & CF_PROTOCOLMASK)
-        *((u_int8*)(rec+fo.prot)) = ui8;
+        *((uint8_t*)(rec+fo.prot)) = ui8;
     }
 
     if (index & CF_TOSMASK) {
       if ((rlen = fread(&ui8, sizeof (ui8), 1, stdin) != 1))
         goto done;
       if (cfdmask & CF_TOSMASK)
-        *((u_int8*)(rec+fo.tos)) = ui8;
+        *((uint8_t*)(rec+fo.tos)) = ui8;
     }
 
     if (index & CF_SRCASMASK) {
@@ -480,7 +479,7 @@ int format0(struct ftio *ftio, struct options *opt)
         goto done;
       ui16 = ntohs(ui16);
       if (cfdmask & CF_SRCASMASK)
-        *((u_int16*)(rec+fo.src_as)) = ui16;
+        *((uint16_t*)(rec+fo.src_as)) = ui16;
     }
 
     if (index & CF_DSTASMASK) {
@@ -488,42 +487,42 @@ int format0(struct ftio *ftio, struct options *opt)
         goto done;
       ui16 = ntohs(ui16);
       if (cfdmask & CF_DSTASMASK)
-        *((u_int16*)(rec+fo.dst_as)) = ui16;
+        *((uint16_t*)(rec+fo.dst_as)) = ui16;
     }
 
     if (index & CF_SRCMASKLENMASK) {
       if ((rlen = fread(&ui8, sizeof (ui8), 1, stdin) != 1))
         goto done;
       if (cfdmask & CF_SRCMASKLENMASK)
-        *((u_int8*)(rec+fo.src_mask)) = ui8;
+        *((uint8_t*)(rec+fo.src_mask)) = ui8;
     }
 
     if (index & CF_DSTMASKLENMASK) {
       if ((rlen = fread(&ui8, sizeof (ui8), 1, stdin) != 1))
         goto done;
       if (cfdmask & CF_DSTMASKLENMASK)
-        *((u_int8*)(rec+fo.dst_mask)) = ui8;
+        *((uint8_t*)(rec+fo.dst_mask)) = ui8;
     }
 
     if (index & CF_TCPFLAGSMASK) {
       if ((rlen = fread(&ui8, sizeof (ui8), 1, stdin) != 1))
         goto done;
       if (cfdmask & CF_TCPFLAGSMASK)
-        *((u_int8*)(rec+fo.tcp_flags)) = ui8;
+        *((uint8_t*)(rec+fo.tcp_flags)) = ui8;
     }
 
     if (index & CF_INPUTENCAPMASK) {
       if ((rlen = fread(&ui8, sizeof (ui8), 1, stdin) != 1))
         goto done;
       if (cfdmask & CF_INPUTENCAPMASK)
-        *((u_int8*)(rec+fo.in_encaps)) = ui8;
+        *((uint8_t*)(rec+fo.in_encaps)) = ui8;
     }
 
     if (index & CF_OUTPUTENCAPMASK) {
       if ((rlen = fread(&ui8, sizeof (ui8), 1, stdin) != 1))
         goto done;
       if (cfdmask & CF_OUTPUTENCAPMASK)
-        *((u_int8*)(rec+fo.out_encaps)) = ui8;
+        *((uint8_t*)(rec+fo.out_encaps)) = ui8;
     }
 
     if (index & CF_PEERNEXTHOPMASK) {
@@ -531,21 +530,21 @@ int format0(struct ftio *ftio, struct options *opt)
         goto done;
       ui32 = ntohl(ui32);
       if (cfdmask & CF_PEERNEXTHOPMASK)
-        *((u_int32*)(rec+fo.peer_nexthop)) = ui32;
+        *((uint32_t*)(rec+fo.peer_nexthop)) = ui32;
     }
 
     if (index & CF_ENGINETYPEMASK) {
       if ((rlen = fread(&ui8, sizeof (ui8), 1, stdin) != 1))
         goto done;
       if (cfdmask & CF_ENGINETYPEMASK)
-        *((u_int8*)(rec+fo.engine_type)) = ui8;
+        *((uint8_t*)(rec+fo.engine_type)) = ui8;
     }
 
     if (index & CF_ENGINEIDMASK) {
       if ((rlen = fread(&ui8, sizeof (ui8), 1, stdin) != 1))
         goto done;
       if (cfdmask & CF_ENGINEIDMASK)
-        *((u_int8*)(rec+fo.engine_id)) = ui8;
+        *((uint8_t*)(rec+fo.engine_id)) = ui8;
     }
 
 
@@ -583,7 +582,7 @@ int format2(struct ftio *ftio, struct options *opt)
   u_char buf[FT_IO_MAXREC];
   char inbuf[1024], *inbufp, *field;
   char *rec, *c;
-  u_int64 dmask, inmask;
+  uint64_t dmask, inmask;
   int ret;
 
   rec = (char*)&buf;
@@ -641,199 +640,199 @@ int format2(struct ftio *ftio, struct options *opt)
     if (inmask & FT_XFIELD_UNIX_SECS) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_UNIX_SECS))
-        *((u_int32*)(rec+fo.unix_secs)) = strtoul(field, (char **)0L, 0);
+        *((uint32_t*)(rec+fo.unix_secs)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_UNIX_NSECS) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_UNIX_NSECS))
-        *((u_int32*)(rec+fo.unix_nsecs)) = strtoul(field, (char **)0L, 0);
+        *((uint32_t*)(rec+fo.unix_nsecs)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_SYSUPTIME) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_SYSUPTIME))
-        *((u_int32*)(rec+fo.sysUpTime)) = strtoul(field, (char **)0L, 0);
+        *((uint32_t*)(rec+fo.sysUpTime)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_EXADDR) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_EXADDR))
-        *((u_int32*)(rec+fo.exaddr)) = scan_ip(field);
+        *((uint32_t*)(rec+fo.exaddr)) = scan_ip(field);
     }
 
     if (inmask & FT_XFIELD_DFLOWS) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_DFLOWS))
-        *((u_int32*)(rec+fo.dFlows)) = strtoul(field, (char **)0L, 0);
+        *((uint32_t*)(rec+fo.dFlows)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_DPKTS) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_DPKTS))
-        *((u_int32*)(rec+fo.dPkts)) = strtoul(field, (char **)0L, 0);
+        *((uint32_t*)(rec+fo.dPkts)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_DOCTETS) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_DOCTETS))
-        *((u_int32*)(rec+fo.dOctets)) = strtoul(field, (char **)0L, 0);
+        *((uint32_t*)(rec+fo.dOctets)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_FIRST) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_FIRST))
-        *((u_int32*)(rec+fo.First)) = strtoul(field, (char **)0L, 0);
+        *((uint32_t*)(rec+fo.First)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_LAST) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_LAST))
-        *((u_int32*)(rec+fo.Last)) = strtoul(field, (char **)0L, 0);
+        *((uint32_t*)(rec+fo.Last)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_ENGINE_TYPE) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_ENGINE_TYPE))
-        *((u_int8*)(rec+fo.engine_type)) = strtoul(field, (char **)0L, 0);
+        *((uint8_t*)(rec+fo.engine_type)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_ENGINE_ID) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_ENGINE_ID))
-        *((u_int8*)(rec+fo.engine_id)) = strtoul(field, (char **)0L, 0);
+        *((uint8_t*)(rec+fo.engine_id)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_SRCADDR) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_SRCADDR))
-        *((u_int32*)(rec+fo.srcaddr)) = scan_ip(field);
+        *((uint32_t*)(rec+fo.srcaddr)) = scan_ip(field);
     }
 
     if (inmask & FT_XFIELD_DSTADDR) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_DSTADDR))
-        *((u_int32*)(rec+fo.dstaddr)) = scan_ip(field);
+        *((uint32_t*)(rec+fo.dstaddr)) = scan_ip(field);
     }
 
     if (inmask & FT_XFIELD_NEXTHOP) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_NEXTHOP))
-        *((u_int32*)(rec+fo.nexthop)) = scan_ip(field);
+        *((uint32_t*)(rec+fo.nexthop)) = scan_ip(field);
     }
 
     if (inmask & FT_XFIELD_INPUT) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_INPUT))
-        *((u_int16*)(rec+fo.input)) = strtoul(field, (char **)0L, 0);
+        *((uint16_t*)(rec+fo.input)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_OUTPUT) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_OUTPUT))
-        *((u_int16*)(rec+fo.output)) = strtoul(field, (char **)0L, 0);
+        *((uint16_t*)(rec+fo.output)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_SRCPORT) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_SRCPORT))
-        *((u_int16*)(rec+fo.srcport)) = strtoul(field, (char **)0L, 0);
+        *((uint16_t*)(rec+fo.srcport)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_DSTPORT) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_DSTPORT))
-        *((u_int16*)(rec+fo.dstport)) = strtoul(field, (char **)0L, 0);
+        *((uint16_t*)(rec+fo.dstport)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_PROT) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_PROT))
-        *((u_int8*)(rec+fo.prot)) = strtoul(field, (char **)0L, 0);
+        *((uint8_t*)(rec+fo.prot)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_TOS) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_TOS))
-        *((u_int8*)(rec+fo.tos)) = strtoul(field, (char **)0L, 0);
+        *((uint8_t*)(rec+fo.tos)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_TCP_FLAGS) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_TCP_FLAGS))
-        *((u_int8*)(rec+fo.tcp_flags)) = strtoul(field, (char **)0L, 0);
+        *((uint8_t*)(rec+fo.tcp_flags)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_SRC_MASK) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_SRC_MASK))
-        *((u_int8*)(rec+fo.src_mask)) = strtoul(field, (char **)0L, 0);
+        *((uint8_t*)(rec+fo.src_mask)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_DST_MASK) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_DST_MASK))
-        *((u_int8*)(rec+fo.dst_mask)) = strtoul(field, (char **)0L, 0);
+        *((uint8_t*)(rec+fo.dst_mask)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_SRC_AS) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_SRC_AS))
-        *((u_int16*)(rec+fo.src_as)) = strtoul(field, (char **)0L, 0);
+        *((uint16_t*)(rec+fo.src_as)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_DST_AS) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_DST_AS))
-        *((u_int16*)(rec+fo.dst_as)) = strtoul(field, (char **)0L, 0);
+        *((uint16_t*)(rec+fo.dst_as)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_IN_ENCAPS) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_IN_ENCAPS))
-        *((u_int8*)(rec+fo.in_encaps)) = strtoul(field, (char **)0L, 0);
+        *((uint8_t*)(rec+fo.in_encaps)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_OUT_ENCAPS) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_OUT_ENCAPS))
-        *((u_int8*)(rec+fo.out_encaps)) = strtoul(field, (char **)0L, 0);
+        *((uint8_t*)(rec+fo.out_encaps)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_PEER_NEXTHOP) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_PEER_NEXTHOP))
-        *((u_int32*)(rec+fo.peer_nexthop)) = scan_ip(field);
+        *((uint32_t*)(rec+fo.peer_nexthop)) = scan_ip(field);
     }
 
     if (inmask & FT_XFIELD_ROUTER_SC) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_ROUTER_SC))
-        *((u_int32*)(rec+fo.router_sc)) = scan_ip(field);
+        *((uint32_t*)(rec+fo.router_sc)) = scan_ip(field);
     }
 
     if (inmask & FT_XFIELD_MARKED_TOS) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_MARKED_TOS))
-        *((u_int8*)(rec+fo.marked_tos)) = strtoul(field, (char **)0L, 0);
+        *((uint8_t*)(rec+fo.marked_tos)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_EXTRA_PKTS) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_EXTRA_PKTS))
-        *((u_int32*)(rec+fo.extra_pkts)) = strtoul(field, (char **)0L, 0);
+        *((uint32_t*)(rec+fo.extra_pkts)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_SRC_TAG) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_SRC_TAG))
-        *((u_int32*)(rec+fo.src_tag)) = strtoul(field, (char **)0L, 0);
+        *((uint32_t*)(rec+fo.src_tag)) = strtoul(field, (char **)0L, 0);
     }
 
     if (inmask & FT_XFIELD_DST_TAG) {
       field = strsep(&inbufp, ",");
       if (field && (dmask & FT_XFIELD_DST_TAG))
-        *((u_int32*)(rec+fo.dst_tag)) = strtoul(field, (char **)0L, 0);
+        *((uint32_t*)(rec+fo.dst_tag)) = strtoul(field, (char **)0L, 0);
     }
       
     if (ftio_write(ftio, rec) < 0) {
@@ -873,7 +872,7 @@ typedef enum { TYPE_IPV4, TYPE_16B, TYPE_32B, TYPE_8B , TYPE_DISCARD,
 	       TYPE_LAST } cvt_t;
 
 struct for2nat_st {
-  u_int64 mask;
+  uint64_t mask;
   cvt_t type;
   int offset;
 };
@@ -934,7 +933,7 @@ int format_NFCollector1(struct ftio *ftio, struct options *opt)
   char inbuf[1024];
   char *rec;
   char *fields[20];
-  u_int64 dmask, imask;
+  uint64_t dmask, imask;
   int ret;
   int debug=ftio_get_debug(ftio);
 
@@ -995,7 +994,7 @@ int format_NFCollector1(struct ftio *ftio, struct options *opt)
   ret = 1;
   while (!(feof(stdin))) {
     char **fp;
-    u_int32 val=0;
+    uint32_t val=0;
     int off=0,n,i;
     if(fgets(inbuf,sizeof(inbuf),stdin) == NULL)
       continue;
@@ -1022,14 +1021,14 @@ int format_NFCollector1(struct ftio *ftio, struct options *opt)
 	}
 	switch(fcv[i].type) {
 	case TYPE_16B:
-	  *((u_int16*)(rec+off)) = (u_int16)val;
+	  *((uint16_t*)(rec+off)) = (uint16_t)val;
 	  break;
 	case TYPE_IPV4:
 	case TYPE_32B:
-	  *((u_int32*)(rec+off)) = (u_int32)val;
+	  *((uint32_t*)(rec+off)) = (uint32_t)val;
 	  break;
 	case TYPE_8B:
-	  *((u_int8*)(rec+off)) = (u_int8)val;
+	  *((uint8_t*)(rec+off)) = (uint8_t)val;
 	case TYPE_DISCARD:
 	case TYPE_LAST:
 	  break; /* Make sun Cpro happy */
@@ -1270,7 +1269,5 @@ void usage(void) {
   fprintf(stderr, "       [-m mask_fields] [-V pdu_version] [-z z_level]\n");
 
 
-  fprintf(stderr, "\n%s version %s: built by %s\n", PACKAGE, VERSION, FT_PROG_BUILD);
-
 } /* usage */
 
