@@ -43,7 +43,6 @@
   #include <string.h>
 #endif
 
-#include "ftbuild.h"
 
 int debug;
 void usage(void);
@@ -58,9 +57,9 @@ int main(int argc, char **argv)
   struct ftset ftset;
   struct fts3rec_offsets fo;
   char *rec;
-  char *fname, *dname;
-  u_int32 total_flows, cap_start, cap_end;
-  u_int32 time_start, time_end;
+  const char *fname, *dname;
+  uint32_t total_flows, cap_start, cap_end;
+  uint32_t time_start, time_end;
   int i, keep_input_time;
 
   /* init fterr */
@@ -219,6 +218,5 @@ void usage(void) {
   fprintf(stderr, "Usage: flow-mask [hk] [-b big|little] [-C comment]\n");
   fprintf(stderr, "       [-d debug_level] [-m mask_fname] [-M mask_definition]\n");
   fprintf(stderr, "       [-z z_level]\n");
-  fprintf(stderr, "\n%s version %s: built by %s\n", PACKAGE, VERSION, FT_PROG_BUILD);
 }
 
