@@ -52,7 +52,6 @@
   #include <string.h>
 #endif
 
-#include "ftbuild.h"
 
 int debug;
 int done;
@@ -88,14 +87,19 @@ int main(int argc, char **argv)
   unsigned int v1, v2;
   fd_set rfd;
   char *out_fname;
-  u_int32 nflows, time_start, time_end;
-  u_int32 flows_corrupt, flows_lost, flows_reset;
-  u_int32 hash;
+  uint32_t nflows, time_start, time_end;
+  uint32_t flows_corrupt, flows_lost, flows_reset;
+  uint32_t hash;
   char fmt_src_ip[32], fmt_dst_ip[32], fmt_dst_port[32];
   char xl_rec[FT_IO_MAXREC], *out_rec;
   int stat_interval, stat_next;
+#ifdef IP_RECVDSTADDR
+#ifdef CMSG_DATA
+  struct cmsghdr *cmsg;
+#endif
+#endif
 
-  time_startup = time((time_t)0L);
+  time_startup = time(NULL);
 
   out_fname = (char*)0L;
   nflows = 0;
@@ -356,7 +360,7 @@ mcast_done:
     ((ftset.z_level) ? FT_IO_FLAG_ZINIT : 0) ) < 0)
     fterr_errx(1, "ftio_init(): failed");
 
-  time_start = (u_int32)time((time_t)0L);
+  time_start = (uint32_t)time(NULL);
 
   ftio_set_comment(&ftio, ftset.comments);
   ftio_set_cap_hostname(&ftio, ftset.hnbuf);
@@ -425,7 +429,7 @@ mcast_done:
       }
     }
 
-    now = time((time_t)0L);
+    now = time(NULL);
 
     /* reset */
     bzero (&tv, sizeof tv);
@@ -489,12 +493,24 @@ restart_recvmsg:
 
 #ifdef IP_RECVDSTADDR
       /* got destination IP back? */
+#ifdef CMSG_DATA
+      for (cmsg = CMSG_FIRSTHDR(&ftnet.msg); cmsg != NULL;
+          cmsg = CMSG_NXTHDR(&ftnet.msg, cmsg)) {
+              if (cmsg->cmsg_level == IPPROTO_IP &&
+                  cmsg->cmsg_type == IP_RECVDSTADDR) {
+                      memcpy(&ftnet.loc_addr.sin_addr.s_addr,
+                          CMSG_DATA(cmsg), sizeof(struct in_addr));
+                      break;
+              }
+      }
+#else
       if ((ftnet.msgip.hdr.cmsg_level == IPPROTO_IP) &&
           (ftnet.msgip.hdr.cmsg_type == IP_RECVDSTADDR)) {
           ftnet.loc_addr.sin_addr.s_addr = ftnet.msgip.ip.s_addr;
       } else {
         ftnet.loc_addr.sin_addr.s_addr = 0;
       }
+#endif /* CMSG_DATA */
 #else
 #ifdef IP_PKTINFO
       if ((ftnet.msgip.hdr.cmsg_level == IPPROTO_IP) &&
@@ -667,7 +683,7 @@ skip1:
   /* rewrite header with updated info */
   if (out_fd_plain) {
   
-    time_end = (u_int32)time((time_t)0L);
+    time_end = (uint32_t)time(NULL);
 
     ftio_set_cap_time(&ftio, time_start, time_end);
     ftio_set_flows_count(&ftio, nflows);
@@ -704,7 +720,6 @@ void usage(void) {
   fprintf(stderr, "       [-f filter_name] [-F filter_definition]\n");
   fprintf(stderr, "       [-t tag_fname] [-T tag_active] [-V pdu_version] [-z z_level]\n");
   fprintf(stderr, "       localip/remoteip/port\n");
-  fprintf(stderr, "\n%s version %s: built by %s\n", PACKAGE, VERSION, FT_PROG_BUILD);
 
 } /* usage */
 
