@@ -50,7 +50,6 @@
   #include <string.h>
 #endif
 
-#include "ftbuild.h"
 
 int debug;
 
@@ -73,10 +72,10 @@ int main(int argc, char **argv)
   struct ftipmask ftipmask;
   void (*xlate)(void *in_rec, void *out_rec);
   char xl_rec[FT_IO_MAXREC], *out_rec;
-  u_int32 privacy_mask;
+  uint32_t privacy_mask;
   unsigned int v1, v2, one;
   int i, n, ret, tx_delay, udp_sock;
-  int src_ip_spoof, hdr_len;
+  int src_ip_spoof, hdr_len = 0;
   void *rec;
 
   /* init fterr */
@@ -389,10 +388,7 @@ again:
 } /* pdu_xmit */
 
 void usage(void) {
-
   fprintf(stderr, "Usage: flow-send [-h] [-d debug_level] [-x xmit_delay] [-V pdu_version]\n");
   fprintf(stderr, "       localip/remoteip/port\n");
-  fprintf(stderr, "\n%s version %s: built by %s\n", PACKAGE, VERSION, FT_PROG_BUILD);
-
 } /* usage */
 
