@@ -43,7 +43,6 @@
   #include <string.h>
 #endif
 
-#include "ftbuild.h"
 
 int debug;
 void usage(void);
@@ -59,10 +58,10 @@ int main(int argc, char **argv)
   struct fts3rec_offsets fo;
   struct ftvar ftvar;
   char *rec, out_rec[FT_IO_MAXREC];
-  char *fname, *dname;
+  const char *fname, *dname;
   unsigned int v1, v2;
-  u_int32 total_flows, cap_start, cap_end;
-  u_int32 time_start, time_end;
+  uint32_t total_flows, cap_start, cap_end;
+  uint32_t time_start, time_end;
   int i, n, keep_input_time;
   int xlate_version;
   int no_config;
@@ -281,6 +280,5 @@ void usage(void) {
   fprintf(stderr, "Usage: flow-xlate [hkn] [-b big|little] [-C comment]\n");
   fprintf(stderr, "       [-d debug_level] [-x xlate_fname] [-X xlate_definition]\n");
   fprintf(stderr, "       [-V version] [-z z_level]\n");
-  fprintf(stderr, "\n%s version %s: built by %s\n", PACKAGE, VERSION, FT_PROG_BUILD);
 }
 
