@@ -31,12 +31,12 @@
 
 #define TCPDUMP_MAGIC 0xa1b2c3d4
 #define TCPDUMP_VERSION_MAJOR 2
-#define TCPDUMP_VERSION_MINOR 2
+#define TCPDUMP_VERSION_MINOR 4
 
 struct pcap_file_header {
   u_long magic;
-  u_short version_major;
-  u_short version_minor;
+  unsigned short version_major;
+  unsigned short version_minor;
   long thiszone;    /* gmt to local correction */
   u_long sigfigs;   /* accuracy of timestamps */
   u_long snaplen;   /* max length saved portion of each pkt */
@@ -45,56 +45,58 @@ struct pcap_file_header {
 
 struct pcap_packet_header {
   struct timeval ts;  /* time stamp */
-  u_long len;         /* length this packet (off wire) */
   u_long caplen;      /* length of portion present */
+  u_long len;         /* length this packet (off wire) */
 };
 
 /* eth header */
 struct pcap_data1 {
   /* eth header */
-  u_int8 eth_dst[6];
-  u_int8 eth_src[6];
-  u_int16 eth_prot;
+  uint8_t eth_dst[6];
+  uint8_t eth_src[6];
+  uint16_t eth_prot;
 };
 
 /* ip header */
 struct pcap_data2 {
-  u_int8 version;
-  u_int8 tos;
-  u_int16 len;
-  u_int16 id;
-  u_int16 flags_fragment;
-  u_int8 ttl;
-  u_int8 prot;
-  u_int16 csum;
-  u_int32 srcaddr;
-  u_int32 dstaddr;
+  uint8_t version;
+  uint8_t tos;
+  uint16_t len;
+  uint16_t id;
+  uint16_t flags_fragment;
+  uint8_t ttl;
+  uint8_t prot;
+  uint16_t csum;
+  uint32_t srcaddr;
+  uint32_t dstaddr;
 };
 
 /* tcp header */
 struct pcap_data3 {
-  u_int16 srcport;
-  u_int16 dstport;
-  u_int32 hold1; /* seq */
-  u_int32 hold2; /* ack */
-  u_int32 hold3; /* data, reserved, flags, window */
-  u_int32 hold4; /* csum, urg pointer */
-  u_int32 hold5; /* options, padding */
+  uint16_t srcport;
+  uint16_t dstport;
+  uint32_t hold1; /* seq */
+  uint32_t hold2; /* ack */
+  uint32_t data_reserved_flags_window; /* data, reserved, flags, window */
+  uint32_t hold4; /* csum, urg pointer */
+  uint32_t hold5; /* options, padding */
 };
 
 
 /* udp header */
 struct pcap_data4 {
-  u_int16 srcport;
-  u_int16 dstport;
-  u_int32 hold1; /* len */
-  u_int32 hold2; /* csum */
-  u_int32 hold3; /* data ...*/
-  u_int32 hold4; /* data ... */
-  u_int32 hold5; /* data ... */
+  uint16_t srcport;
+  uint16_t dstport;
+  uint16_t len; /* len */
+  uint16_t csum; /* csum */
+#if 0 /* { */
+  uint32_t hold3; /* data ...*/
+  uint32_t hold4; /* data ... */
+  uint32_t hold5; /* data ... */
 #ifdef XXX
-  u_int32 hold6; /* data */
+  uint32_t hold6; /* data */
 #endif /* XXX */
+#endif /* } */
 };
 
 
